// Instalment payments - SBIF does not have instalment payment information (cuota), so it must be derived from imputing interest rate plus using the maturity information
use "$path_s1\EFH_SBIF_wide_${yk}.dta", clear
if ${yk}==11 {  // Tenencias de Deuda (Ownership of Debt) in EFH
global tcc = 4 
local tcc = ${tcc}
local mvars "m1 m2 m3"
local ccvar2 = "f21"
}
if ${yk}==14 {
global tcc = 5
local tcc = ${tcc}
local mvars "n1"
local ccvar2 = "f24"
}
local tefh1 = 1
local tefh2 = ${tcc}
local tefh5 = 2
sum year_mortgage_*_EFH month_mortgage_*_EFH

// Consumer Credit - Loan Amounts - SBIF   //
sum date_survey
local date1 = r(min) //${date1}
local date2 = r(max) //${date2}
local tdebt1 = "tarjeta"  // Consumo: *1 Tarjetas de crdito *2 Crdito en cuotas *3 Crditos a estudiantes Recursos CORFO
local tdebt2 = "prestamo" // 4 Otros crditos de consumo *5 Lneas de crdito en cuenta corriente
local tdebt5 = "linea"
g error_amount = 0
g abs_error_amount = 0
g abs_error_amount2 = 0
quietly  {
foreach td of numlist 1 2 5 { 
g cuota_`tdebt`td''_SBIF = 0
forv kd1=`date1'/`date2' {
local kd3=`kd1'
capture egen cuota_deu`td'_`kd3' = rowtotal(cuota_deu`td'_*_`kd3')
capture replace cuota_`tdebt`td''_SBIF = cuota_deu`td'_`kd3' if deuda_`tdebt`td''_SBIF==1 & date_survey==`kd1'
capture replace error_amount = max(0,cuota_`tdebt`td''_SBIF)-max(0,cuota_`tdebt`td''_EFH)
capture replace abs_error_amount = abs(error_amount)

forv tn=1/4 {
capture replace cuota_`tdebt`td''_SBIF = max(0,cuota_`tdebt`td''_SBIF) + max(0,cuota_deu4_`tn'_`kd3') if deuda_`tdebt`td''_SBIF==1 & error_amount<0 & abs_error_amount>cuota_deu4_`tn'_`kd3' & date_survey==`kd1'
capture replace error_amount = max(0,cuota_`tdebt`td''_SBIF)-max(0,cuota_`tdebt`td''_EFH)
capture replace abs_error_amount = abs(error_amount)
}
capture drop cuota_deu`td'_`kd3' 
foreach kd2 of numlist -1 1 -2 2 {  //forv kd2=-2/2 {
local kd3=`kd1'+`kd2'
capture egen cuota_deu`td'_`kd3' = rowtotal(cuota_deu`td'_*_`kd3')
capture replace abs_error_amount2 = abs(max(0,cuota_deu`td'_`kd3')-max(0,cuota_`tdebt`td''_EFH))
capture replace cuota_`tdebt`td''_SBIF = cuota_deu`td'_`kd3' if deuda_`tdebt`td''_SBIF==1 & abs_error_amount>abs_error_amount2 & cuota_deu`td'_`kd3'>0 & cuota_deu`td'_`kd3'<. & date_survey==`kd1'
capture replace error_amount = max(0,cuota_`tdebt`td''_SBIF)-max(0,cuota_`tdebt`td''_EFH)
capture replace abs_error_amount = abs(error_amount)
forv tn=1/4 {
capture replace cuota_`tdebt`td''_SBIF = max(0,cuota_`tdebt`td''_SBIF) + max(0,cuota_deu4_`tn'_`kd3') if deuda_`tdebt`td''_SBIF==1 & error_amount<0 & abs_error_amount>cuota_deu4_`tn'_`kd3' & date_survey==`kd1'
capture replace error_amount = max(0,cuota_`tdebt`td''_SBIF)-max(0,cuota_`tdebt`td''_EFH)
capture replace abs_error_amount = abs(error_amount)
}
capture drop cuota_deu`td'_`kd3' 
}
}
}
}
//   ReConsider Loans from other Non-Interviewed Household members //
quietly {
foreach td of numlist 1 2 5 { //replace f10_t`tk'd`dk' = . if f3_t`tk'd`dk'>1 
forv dk=1/3 {   // Loan amount in EFH for non-interviewed members
capture replace error_amount = max(0,cuota_`tdebt`td''_SBIF)-max(0,cuota_`tdebt`td''_EFH)
capture replace abs_error_amount = abs(error_amount)
capture replace cuota_`tdebt`td''_EFH = max(0,cuota_`tdebt`td''_EFH)+max(0,f10_t`tefh`tk''d`dk') if f3_t`tefh`tk''d`dk'>1 & error_amount>0  & abs_error_amount>f10_t`tefh`tk''d`dk' & f10_t`tefh`tk''d`dk'<.
}
}
}
quietly { // Reconsider Crdito Complementario as Prstamos de Consumo
forv dk=1/4 { // Only for Prestamos de Consumo
capture replace error_amount = max(0,cuota_prestamo_SBIF)-max(0,cuota_prestamo_EFH)
capture replace abs_error_amount = abs(error_amount)
capture replace cuota_prestamo_EFH = max(0,cuota_prestamo_EFH)+max(0,complementario_m_`dk'_EFH') if complementario_m_`dk'_EFH<. & error_amount>0 & abs_error_amount>complementario_m_`dk'_EFH
}
}
replace cuota_TL_EFH = max(0,cuota_tarjeta_EFH) + max(0,cuota_linea_EFH) if deuda_TL_EFH==1 
replace cuota_banco_EFH = max(0,cuota_TL_EFH) + max(0,cuota_prestamo_EFH) if deuda_banco_EFH==1 
foreach td of numlist 1 2 5 { 
capture replace cuota_`tdebt`td''_SBIF = . if deuda_`tdebt`td''_SBIF==0
capture replace cuota_`tdebt`td''_SBIF = . if cuota_`tdebt`td''_SBIF==0 //capture replace deuda_`tdebt`td''_SBIF = 0 if cuota_`tdebt`td''_SBIF==.
}
egen cuota_TL_SBIF = rowtotal(cuota_tarjeta_SBIF cuota_linea_SBIF), missing
egen cuota_banco_SBIF = rowtotal(cuota_tarjeta_SBIF cuota_linea_SBIF cuota_prestamo_SBIF), missing
drop error_amount abs_error_amount abs_error_amount2

// Mortgage Credit - SBIF   //
g cuota_hipotecario_SBIF = 0   
g error_amount = 0
g abs_error_amount = 0
g abs_error_amount2 = 0
quietly  {
forv kd1=`date1'/`date2' {
local kd3=`kd1'
capture egen cuota_deu_hip_`kd3' = rowtotal(cuota_deu6_*_`kd3' cuota_deu7_*_`kd3' cuota_deu9_*_`kd3' cuota_deu10_*_`kd3')
capture replace cuota_hipotecario_SBIF = cuota_deu_hip_`kd3' if hipotecario_SBIF==1 & date_survey==`kd1'
capture replace error_amount = max(0,cuota_hipotecario_SBIF)-max(0,cuota_hipotecario_EFH)
capture replace abs_error_amount = abs(error_amount)

capture drop cuota_deu_hip_`kd3' 
foreach kd2 of numlist -1 1 -2 2 {  //forv kd2=-2/2 {
local kd3=`kd1'+`kd2'
capture egen cuota_deu_hip_`kd3' = rowtotal(cuota_deu6_*_`kd3' cuota_deu7_*_`kd3' cuota_deu9_*_`kd3' cuota_deu10_*_`kd3')
capture replace abs_error_amount2 = abs(max(0,cuota_deu_hip_`kd3')-max(0,cuota_hipotecario_EFH))
capture replace cuota_hipotecario_SBIF = cuota_deu_hip_`kd3' if cuota_hipotecario_SBIF==1 & abs_error_amount>abs_error_amount2 & cuota_deu_hip_`kd3'>0 & cuota_deu_hip_`kd3'<. & date_survey==`kd1'
capture replace error_amount = max(0,cuota_hipotecario_SBIF)-max(0,cuota_hipotecario_EFH)
capture replace abs_error_amount = abs(error_amount)
capture drop cuota_deu_hip_`kd3' 
}
}
}
foreach x of varlist cuota_hipotecario_SBIF nr_mortgages_SBIF_all error_amount abs_error_amount abs_error_amount2 {
replace `x'=. if hipotecario_SBIF==. //replace `x'=. if hipotecario_SBIF==0 //capture replace `x' = . if possible_prior_mortgage==1 //blc
}
drop error_amount abs_error_amount abs_error_amount2

//  Errors of EFH vs SBIF
local debt_types2 "hipotecario banco prestamo TL tarjeta linea"
foreach x of local debt_types2 {
g error_`x'_cuota = max(0,cuota_`x'_SBIF) - max(0,cuota_`x'_EFH) if cuota_`x'_SBIF<. | cuota_`x'_EFH<.  
if ${Ratio_op}==1 { //ln( (abs(error_`x'_monto)+ 1) )  //+ r(min)
g mean_var = ( max(0,cuota_`x'_EFH ) + max(0,cuota_`x'_SBIF ) )/2 
g error_ratio_cuota_`x' =  abs(error_`x'_cuota)/mean_var 
g error_ratio0_cuota_`x' =  error_`x'_cuota/mean_var 
drop mean_var
}
else  {
g error_ratio_cuota_`x' =  abs(error_`x'_cuota)/cuota_`x'_SBIF  
replace error_ratio_cuota_`x' =  abs(error_`x'_cuota)/cuota_`x'_EFH if error_ratio_cuota_`x'==.                    
}
}      
save "$path_s1\EFH_SBIF_wide_${yk}.dta", replace
