***************************************************************************************
* ANALISIS RESUMIDO DE LAS REGRESIONES
***************************************************************************************


* Base regresiones
*use "N:\DPF\GIF\Investigación Financiera\Investigación\Proyectos\2017\Cruce_EFH_SBIF_PM_FM_PR\Cruce_vCM\Bases CM\Regresion\analysis11_14_17.dta", clear
*use "/Users/paulamargaretic/Dropbox/Cruce/Paper descriptivo/Stata/Bases y dofiles CM/Regresion/analysis11_14_17.dta"
use "/Users/paulamargaretic/Dropbox/Cruce/Paper descriptivo/Stata/dta/variables_EFH_2011_2014_2017.dta", clear
merge 1:1 folio yearEFH using "/Users/paulamargaretic/Dropbox/Cruce/Paper descriptivo/Stata/dta/analysis11_14_17_vfix.dta"


***************************************************************************************
* Variables explicativas
***************************************************************************************

drop edad2
gen edad2=edad*edad

gen edad_d=int(edad/10)
label var edad_d "Age (in decades)"
g edadsq=edad_d*edad_d
label var edadsq "Age (in decades) squared"
gen terc_educ=(neduc>3)
label var terc_educ "Interviewed holds a post-secondary degree"
gen relationship =(est_civ==2)
label var relationship "In a relationship"
gen sobr_end=(perc_end==1|perc_end==2)
label var sobr_end "Household feels over-indebted"
gen       int_knowledge=(x_n3==3)
label var int_knowledge   "Good knowledge of the interviewed"
gen       int_disposition=(x_n5==3)
label var int_disposition "Good disposition of the interviewed"
g c6_act_indef2=c6_act_indef 
recode c6_act_indef2 2=1 7=1 4=3 6=3
lab def c6_act_indef2 1 "Self-employed" 3 "Civil servant" 5 "Private sector" 8 "Inactive or unemployed" 9 "Pensioner", modify
label values c6_act_indef2 c6_act_indef2
label var c6_act_indef2 "Occupational status"
gen n_cconhip=n_ccon+n_chip
label var n_cconhip "Number of loans"
gen p_estrato3   =(estrato==3)
label var p_estrato3 "If household belongs to highest 2 deciles"
/* Not working here
gen tipo_d=(tipo==9)
label var tipo_d "Type of banking debt"
lab def tipo_d 0 "Installment loan" 1 "Mortgage loan" , modify
label values tipo_d tipo_d
*/
gen education=1 if neduc==1 | neduc==2
replace education=2 if neduc==3
replace education=3 if neduc==4
replace education=4 if neduc==5
label var education "Education"
lab def education 1 "Only school" 2 "Technical education" 3 "University" 4 "Postgraduate" , modify
label values education education

gen male_nmarried=(genero==1 & married==0)
label var male_nmarried "Male, not married"
bys folio year_efh:egen atr_12m_h=max(atr_12m)
label var atr_12m_h "Interviewed has had credit arrears in last 12 months"

***************************************************************************************
* Version PM, with debt ownership status (EFH=1,SBIF=0)
***************************************************************************************
global explic_var1 "n_act  male_nmarried married i.education edad_d edadsq"             
global explic_var2 "male_nmarried married i.education edad_d edadsq"             
global explic_var3 "male_nmarried married i.education edad_d edadsq i.ocup i.sexo"             

*------
global adicional   "numh i.n_encuestados n_ing n_cconhip d_transf i.macrozona refresco jefe_hog i.yearEFH"
global adicional2  "numh i.n_encuestados n_cconhip n_ingact gen_ing d_transf i.macrozona refresco i.yearEFH"
global adicional3  "numh n_cconhip n_ingact gen_ing d_transf i.macrozona "


set more off
logit error_mortgageEFH_notSBIF $explic_var3 $adicional2 [pw=factor_egm], vce(cluster folio)

logit error_mortgageEFH_notSBIF $explic_var3 $adicional3  [pw=factor_egm], vce(cluster folio)
logit error_mortgageEFH_notSBIF $explic_var3 $adicional3  if yearEFH==2017 [pw=factor_egm], vce(cluster folio)

logit error_mortgageEFH_notSBIF $explic_var3 $adicional3 a1_nothighest_income nr_y_max a1_nothighest_age  [pw=factor_egm],  vce(cluster folio)
logit error_mortgageEFH_notSBIF $explic_var3 $adicional3 a1_nothighest_income nr_y_max a1_nothighest_age if yearEFH==2017 [pw=factor_egm],  vce(cluster folio)


logit error_prestamoEFH_notSBIF $explic_var3 $adicional3  [pw=factor_egm], vce(cluster folio)
logit error_prestamoEFH_notSBIF $explic_var3 $adicional3 a1_nothighest_income nr_y_max a1_nothighest_age [pw=factor_egm],  vce(cluster folio)


***************************************************************************************
* Version PM, with proportional errors
***************************************************************************************
local debt_types2 "hipotecario prestamo TL"
local error_types0 "ratio0" //ratio0_cuota
local K=1
foreach x of local debt_types2 { //g E_`x'_monto`pp' = error_`x'_monto if deuda_`x'_EFH==1 & deuda_`x'_SBIF==1
display("`x'")
foreach x2 of local error_types0 {
g E_`x2'_`x' = 100*abs(error_`x2'_`x') if error_`x2'_`x'>-2 & error_`x2'_`x'<2  //make them in %
*reg E_`x2'_`x' a1_nothighest_income nr_y_max a1_nothighest_age if deuda_`x'_EFH==1 & deuda_`x'_SBIF==1 [pw=factor_egm]
}
}

reg E_ratio0_hipotecario $explic_var3 $adicional3 if deuda_hipotecario_EFH==1 & deuda_hipotecario_SBIF==1 [pw=factor_egm], vce(cluster folio)
reg E_ratio0_hipotecario $explic_var3 $adicional3 a1_nothighest_income nr_y_max a1_nothighest_age if deuda_hipotecario_EFH==1 & deuda_hipotecario_SBIF==1 [pw=factor_egm], vce(cluster folio)

reg E_ratio0_prestamo $explic_var3 $adicional3 if deuda_prestamo_EFH==1 & deuda_prestamo_SBIF==1 [pw=factor_egm], vce(cluster folio)
reg E_ratio0_prestamo $explic_var3 $adicional3 a1_nothighest_income nr_y_max a1_nothighest_age if deuda_prestamo_EFH==1 & deuda_prestamo_SBIF==1 [pw=factor_egm], vce(cluster folio)

reg E_ratio0_TL $explic_var3 $adicional3 if deuda_TL_EFH==1 & deuda_TL_SBIF==1 [pw=factor_egm], vce(cluster folio)
reg E_ratio0_TL $explic_var3 $adicional3 a1_nothighest_income nr_y_max a1_nothighest_age if deuda_TL_EFH==1 & deuda_TL_SBIF==1 [pw=factor_egm], vce(cluster folio)
