***************************************************************************************
* ANALISIS REGRESIONES PARA TESTEO HIPOTESIS
***************************************************************************************


* Base regresiones
use "/Users/paulamargaretic/Dropbox/Cruce/Paper descriptivo/Stata/dta/analysis11_14_17_vfix_long.dta", replace

***************************************************************************************
* Variables explicativas
***************************************************************************************

gen edad2=edad*edad
gen edad_d=int(edad/10)
label var edad_d "Age (in decades)"
g edadsq=edad_d*edad_d
label var edadsq "Age (in decades) squared"
gen terc_educ=(neduc>3)
label var terc_educ "Interviewed holds a post-secondary degree"
gen relationship =(est_civ==2)
label var relationship "In a relationship"
gen sobr_end=(perc_end==1|perc_end==2)
label var sobr_end "Household feels over-indebted"
gen       int_knowledge=(x_n3==3)
label var int_knowledge   "Good knowledge of the interviewed"
gen       int_disposition=(x_n5==3)
label var int_disposition "Good disposition of the interviewed"
g c6_act_indef2=c6_act_indef 
recode c6_act_indef2 2=1 7=1 4=3 6=3
lab def c6_act_indef2 1 "Self-employed" 3 "Civil servant" 5 "Private sector" 8 "Inactive or unemployed" 9 "Pensioner", modify
label values c6_act_indef2 c6_act_indef2
label var c6_act_indef2 "Occupational status"
gen n_cconhip=n_ccon+n_chip
label var n_cconhip "Number of loans"
gen p_estrato3   =(estrato==3)
label var p_estrato3 "If household belongs to highest 2 deciles"
/* Not working here
gen tipo_d=(tipo==9)
label var tipo_d "Type of banking debt"
lab def tipo_d 0 "Installment loan" 1 "Mortgage loan" , modify
label values tipo_d tipo_d
*/
gen education=1 if neduc==1 | neduc==2
replace education=2 if neduc==3
replace education=3 if neduc==4
replace education=4 if neduc==5
label var education "Education"
lab def education 1 "Only school" 2 "Technical education" 3 "University" 4 "Postgraduate" , modify
label values education education

gen male_nmarried=(genero==1 & married==0)
label var male_nmarried "Male, not married"
/*bys folio yearEFH: egen atr_12m_h=max(atr_12m)
label var atr_12m_h "Interviewed has had credit arrears in last 12 months"
*/

***************************************************************************************
* Replicating table 8 on the maximum income member
***************************************************************************************

*Case (EFH=1,SBIF=0)
* Mortgages
tab d_nomax_ing if (deuda_hipotecario_SBIF==0 & deuda_hipotecario_EFH==1 & reporut_2017!=0 )
* IL
tab d_nomax_ing if (deuda_prestamo_SBIF==0 & deuda_prestamo_EFH==1 & reporut_2017!=0 )
* TL
tab d_nomax_ing if ((deuda_tarjeta_SBIF==0 & deuda_tarjeta_EFH==1 & reporut_2017!=0 ) | (deuda_linea_SBIF==0 & deuda_linea_EFH==1 & reporut_2017!=0 ))

*Case (EFH=1,SBIF=1)
* Mortgages
tab d_nomax_ing if (deuda_hipotecario_SBIF==1 & deuda_hipotecario_EFH==1 & reporut_2017!=0 )
* IL
tab d_nomax_ing if (deuda_prestamo_SBIF==1 & deuda_prestamo_EFH==1 & reporut_2017!=0 )
* TL
tab d_nomax_ing if ((deuda_tarjeta_SBIF==1 & deuda_tarjeta_EFH==1 & reporut_2017!=0 ) | (deuda_linea_SBIF==1 & deuda_linea_EFH==1 & reporut_2017!=0 ))

***************************************************************************************
* Globals and additional variable definiions
***************************************************************************************
egen id=group(folio yearEFH)

global explic_var1 "male_nmarried married i.education edad_d edadsq"             
global explic_var2 "male_nmarried married i.education edad edad2"             
global explic_var3 " married i.education edad_d edadsq i.c6_act_indef2 i.genero"             
global explic_var4 " married i.education edad edad2 i.c6_act_indef2 i.genero i.estrato i.macrozona"             
global explic_var5 " married i.education edad edad2 i.c6_act_indef2 i.genero i.macrozona"             

*------
global adicional   "numh i.n_encuestados n_ing n_cconhip d_transf i.macrozona refresco jefe_hog i.yearEFH"
global adicional2  "numh i.n_encuestados n_cconhip n_ingact gen_ing d_transf i.macrozona refresco i.yearEFH"
global adicional3  "numh n_cconhip n_ingact gen_ing d_transf i.macrozona "
global adicional4  "numh n_cconhip n_ing n_act gen_ing d_transf i.refresco i.yearEFH"
global adicional5 "numh n_cconhip n_ingact gen_ing d_transf i.refresco "
global adicional6 "numh n_cconhip n_ingact gen_ing d_transf i.refresco i.tipo_deudar"
global adicional7 "n_act gen_ing d_transf i.refresco ib2.tipo_deudar"
global adicional8 "n_act d_transf gen_ing i.refresco "
global adicional9 "i.refresco i.yearEFH i.estrato"
*global adicional9 "n_ingact i.refresco i.yearEFH"
global adicional10 "d_nomax_ing i.refresco i.yearEFH i.estrato"
global adicional11 "gen_ing i.refresco i.yearEFH "

* Proportional error definition
g E_error_ratio0 = 100*abs(error_ratio0) if error_ratio0>=-2 & error_ratio0<=2  //make them in %

* Debt types
g tipo_deudar=tipo_deuda
replace tipo_deudar = 2 if (tipo_deuda == 2| tipo_deuda == 4)
lab def tipo_deudar 1 "Mortgages" 2 "Credit card and lines" 3 "Installment loans" , modify
label values tipo_deudar tipo_deudar

* TL to the logit 
replace error_EFH_notSBIF=0 if (deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==1) ///
							| (deuda_linea_EFH==1 & deuda_linea_SBIF==1)
replace error_EFH_notSBIF=1 if (deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==0) ///
							| (deuda_linea_EFH==1 & deuda_linea_SBIF==0)


***************************************************************************************
* Regressions with debt ownership status (EFH=1,SBIF=0)
***************************************************************************************
cd "/Users/paulamargaretic/Dropbox/Cruce/Paper descriptivo/Stata/tablas"

set more off
logit error_EFH_notSBIF $explic_var4 $adicional10 i.tipo_deudar if reporut_2017!=0 [pw=factor_egm], vce(cluster id)
outreg2 using "Regresiones_PM_logit.xls" , append ctitle(All)

logit error_EFH_notSBIF $explic_var4 $adicional10 if tipo_deuda==1 & reporut_2017!=0 [pw=factor_egm], vce(cluster id)
outreg2 using "Regresiones_PM_logit.xls" , append ctitle(Hipot)
logit error_EFH_notSBIF $explic_var4 $adicional10 if tipo_deuda==3  & reporut_2017!=0 [pw=factor_egm], vce(cluster id)
outreg2 using "Regresiones_PM_logit.xls" , append ctitle(IL)

logit error_EFH_notSBIF $explic_var4 $adicional10 if (tipo_deuda==2 | tipo_deuda==4) & reporut_2017!=0  [pw=factor_egm], vce(cluster id)
outreg2 using "Regresiones_PM_logit.xls" , append ctitle(TL)

* Robustness with gen_ing
set more off
logit error_EFH_notSBIF $explic_var5 $adicional11 i.tipo_deudar if reporut_2017!=0 [pw=factor_egm], vce(cluster id)
outreg2 using "Regresiones_PM_logit.xls" , append ctitle(All)

logit error_EFH_notSBIF $explic_var5 $adicional11 if tipo_deuda==1 & reporut_2017!=0 [pw=factor_egm], vce(cluster id)
outreg2 using "Regresiones_PM_logit.xls" , append ctitle(Hipot)
logit error_EFH_notSBIF $explic_var5 $adicional11 if tipo_deuda==3  & reporut_2017!=0 [pw=factor_egm], vce(cluster id)
outreg2 using "Regresiones_PM_logit.xls" , append ctitle(IL)

logit error_EFH_notSBIF $explic_var4 $adicional11 if (tipo_deuda==2 | tipo_deuda==4) & reporut_2017!=0  [pw=factor_egm], vce(cluster id)
outreg2 using "Regresiones_PM_logit.xls" , append ctitle(TL)

* To be reported 
***************************************************************************************
set more off
logit error_EFH_notSBIF $explic_var4 $adicional10 i.tipo_deudar if reporut_2017!=0 [pw=factor_egm], vce(cluster id)
outreg2 using "Regresiones_PM_logit.xls" , append ctitle(All)

logit error_EFH_notSBIF $explic_var4 $adicional10 if tipo_deuda==1 & reporut_2017!=0 [pw=factor_egm], vce(cluster id)
outreg2 using "Regresiones_PM_logit.xls" , append ctitle(Hipot)
logit error_EFH_notSBIF $explic_var4 $adicional10 if tipo_deuda==3  & reporut_2017!=0 [pw=factor_egm], vce(cluster id)
outreg2 using "Regresiones_PM_logit.xls" , append ctitle(IL)

logit error_EFH_notSBIF $explic_var4 $adicional10 if (tipo_deuda==2 | tipo_deuda==4) & reporut_2017!=0  [pw=factor_egm], vce(cluster id)
outreg2 using "Regresiones_PM_logit.xls" , append ctitle(TL)

***************************************************************************************
* Regressions with proportional errors
***************************************************************************************
* To test the hypothesis on willingness

foreach v in x_n5 disp_efhnext lug_entrev prob_resp dif_acep int_knowledge int_disposition {
tab yearEFH `v'
}

* Conditional model
***************************************************************************************
* All
set more off
reg E_error_ratio0 $explic_var5 $adicional9 ib2.conoc_fondo i.sof_fin i.x_n5 dow  if ((deuda_hipotecario_EFH==1 & deuda_hipotecario_SBIF==1) | ///
(deuda_prestamo_EFH==1 & deuda_prestamo_SBIF==1) | ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==1)| (deuda_linea_EFH==1 & deuda_linea_SBIF==1))) ///
& reporut_2017!=0 [pw=factor_egm], vce(cluster id) 
outreg2 using "Regresiones_PM_error.xls" , append ctitle(All)

* Hipotecario
reg E_error_ratio0 $explic_var5 $adicional9 ib2.conoc_fondo i.sof_fin i.x_n5  dow if (deuda_hipotecario_EFH==1 & deuda_hipotecario_SBIF==1) & reporut_2017!=0 [pw=factor_egm], vce(cluster id) 
outreg2 using "Regresiones_PM_error.xls" , append ctitle(Hipot)

reg E_error_ratio0 $explic_var5 $adicional9 ib2.conoc_fondo i.sof_fin i.x_n5  dow if (deuda_prestamo_EFH==1 & deuda_prestamo_SBIF==1) & reporut_2017!=0 [pw=factor_egm], vce(cluster id) 
outreg2 using "Regresiones_PM_error.xls" , append ctitle(IL)

reg E_error_ratio0 $explic_var5 $adicional9 ib2.conoc_fondo i.sof_fin i.x_n5  dow if ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==1)| (deuda_linea_EFH==1 & deuda_linea_SBIF==1)) & reporut_2017!=0 [pw=factor_egm], vce(cluster id) 
outreg2 using "Regresiones_PM_error.xls" , append ctitle(TL)

* Rob check
* All
set more off
reg E_error_ratio0 $explic_var5 $adicional9 ib2.conoc_fondo i.sof_fin i.x_n5 i.int_knowledge dow  if ((deuda_hipotecario_EFH==1 & deuda_hipotecario_SBIF==1) | ///
(deuda_prestamo_EFH==1 & deuda_prestamo_SBIF==1) | ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==1)| (deuda_linea_EFH==1 & deuda_linea_SBIF==1))) ///
& reporut_2017!=0 [pw=factor_egm], vce(cluster id) 
outreg2 using "Regresiones_PM_error.xls" , append ctitle(All)

* Hipotecario
reg E_error_ratio0 $explic_var5 $adicional9 ib2.conoc_fondo i.sof_fin i.x_n5 i.int_knowledge dow if (deuda_hipotecario_EFH==1 & deuda_hipotecario_SBIF==1) & reporut_2017!=0 [pw=factor_egm], vce(cluster id) 
outreg2 using "Regresiones_PM_error.xls" , append ctitle(Hipot)

reg E_error_ratio0 $explic_var5 $adicional9 ib2.conoc_fondo i.sof_fin i.x_n5 i.int_knowledge dow if (deuda_prestamo_EFH==1 & deuda_prestamo_SBIF==1) & reporut_2017!=0 [pw=factor_egm], vce(cluster id) 
outreg2 using "Regresiones_PM_error.xls" , append ctitle(IL)

reg E_error_ratio0 $explic_var5 $adicional9 ib2.conoc_fondo i.sof_fin i.x_n5 i.int_knowledge dow if ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==1)| (deuda_linea_EFH==1 & deuda_linea_SBIF==1)) & reporut_2017!=0 [pw=factor_egm], vce(cluster id) 
outreg2 using "Regresiones_PM_error.xls" , append ctitle(TL)


* Unconditional model
***************************************************************************************
/*
set more off
reg E_error_ratio0 $explic_var1 if reporut_2017!=0 [pw=factor_egm], vce(cluster id)
reg E_error_ratio0 $explic_var2 if reporut_2017!=0 [pw=factor_egm], vce(cluster id)
reg E_error_ratio0 $explic_var3 if reporut_2017!=0 [pw=factor_egm], vce(cluster id)
reg E_error_ratio0 $explic_var4 if reporut_2017!=0 [pw=factor_egm], vce(cluster id)

set more off
reg E_error_ratio0 $explic_var4 $adicional if reporut_2017!=0 [pw=factor_egm], vce(cluster id)
reg E_error_ratio0 $explic_var4 $adicional2 if reporut_2017!=0 [pw=factor_egm], vce(cluster id)
reg E_error_ratio0 $explic_var4 $adicional3 if reporut_2017!=0 [pw=factor_egm], vce(cluster id)
set more off
reg E_error_ratio0 $explic_var4 $adicional4 if reporut_2017!=0 [pw=factor_egm], vce(cluster id)
reg E_error_ratio0 $explic_var4 $adicional5 if reporut_2017!=0 [pw=factor_egm], vce(cluster id)
reg E_error_ratio0 $explic_var4 $adicional6 if reporut_2017!=0 [pw=factor_egm], vce(cluster id)
reg E_error_ratio0 $explic_var4 $adicional7 if reporut_2017!=0 [pw=factor_egm], vce(cluster id)
reg E_error_ratio0 $explic_var4 $adicional8 if reporut_2017!=0 [pw=factor_egm], vce(cluster id)
reg E_error_ratio0 $explic_var4 $adicional9 if reporut_2017!=0 [pw=factor_egm], vce(cluster id)

reg E_error_ratio0 $explic_var4 $adicional8 if deuda_hipotecario_EFH==1 & deuda_hipotecario_SBIF==1 & reporut_2017!=0 [pw=factor_egm], vce(cluster id)
reg E_error_ratio0 $explic_var4 $adicional9 if deuda_hipotecario_EFH==1 & deuda_hipotecario_SBIF==1 & reporut_2017!=0 [pw=factor_egm], vce(cluster id)

reg E_error_ratio0 $explic_var4 $adicional8 if tipo_deuda==1 & reporut_2017!=0 [pw=factor_egm], vce(cluster id)
reg E_error_ratio0 $explic_var4 $adicional9 if tipo_deuda==1 & reporut_2017!=0 [pw=factor_egm], vce(cluster id)

reg E_error_ratio0 $explic_var3 $adicional8 if ((tipo_deuda==2 |tipo_deuda==4) & reporut_2017!=0) [pw=factor_egm], vce(cluster folio)
reg E_error_ratio0 $explic_var4 $adicional9 if ((tipo_deuda==2 |tipo_deuda==4) & reporut_2017!=0) [pw=factor_egm], vce(cluster id)

reg E_error_ratio0 $explic_var3 $adicional8 if tipo_deuda==3 & reporut_2017!=0 [pw=factor_egm], vce(cluster folio)
reg E_error_ratio0 $explic_var4 $adicional9 if tipo_deuda==3 & reporut_2017!=0 [pw=factor_egm], vce(cluster id)

* To be reported
***************************************************************************************
set more off
cd "/Users/paulamargaretic/Dropbox/Cruce/Paper descriptivo/Stata/tablas"
reg E_error_ratio0 $explic_var4 $adicional9 i.tipo_deudar if reporut_2017!=0 [pw=factor_egm], vce(cluster id)
outreg2 using "Regresiones_PM_error.xls" , append ctitle(All)

reg E_error_ratio0 $explic_var4 $adicional9 if tipo_deuda==1 & reporut_2017!=0 [pw=factor_egm], vce(cluster id)
outreg2 using "Regresiones_PM_error.xls" , append ctitle(Hipot)

reg E_error_ratio0 $explic_var4 $adicional9 if ((tipo_deuda==2 |tipo_deuda==4) & reporut_2017!=0) [pw=factor_egm], vce(cluster id)
outreg2 using "Regresiones_PM_error.xls" , append ctitle(TL)
reg E_error_ratio0 $explic_var4 $adicional9 if tipo_deuda==3  & reporut_2017!=0 [pw=factor_egm], vce(cluster id)
outreg2 using "Regresiones_PM_error.xls" , append ctitle(IL)


* To be reported in an appendix
***************************************************************************************
set more off
reg E_error_ratio0 $explic_var4 $adicional8 i.tipo_deudar if reporut_2017!=0 [pw=factor_egm], vce(cluster id)

reg E_error_ratio0 $explic_var4 $adicional8 if tipo_deuda==1 & reporut_2017!=0 [pw=factor_egm], vce(cluster id)
reg E_error_ratio0 $explic_var3 $adicional8 if ((tipo_deuda==2 |tipo_deuda==4) & reporut_2017!=0) [pw=factor_egm], vce(cluster id)
reg E_error_ratio0 $explic_var3 $adicional8 if tipo_deuda==3 & reporut_2017!=0 [pw=factor_egm], vce(cluster id)
*/
