***************************************************************************************
* ANALISIS REGRESIONES INCLUYENDO EFECTOS FIJOS DE ENCUESTADORES
***************************************************************************************

* Base regresiones
global path "C:\Users\pedro\Dropbox\Cruce\Paper descriptivo\Stata"
use "$path\dta\analysis11_14_17_vfix_long.dta", replace

******************************************************
* Unimos bases
******************************************************
*joinby folio yearEFH tipo_deuda using "$path\dta\informacion_deudas.dta", unm(b)
joinby folio yearEFH tipo_deuda using "$path/dta/informacion_deudas.dta", unm(b)
tab _merge
rename _merge _merge1

* Interviewers' database (only 2014 & 2017)
merge m:1 folio yearEFH  using "$path\dta\base_enc_2014_2017.dta"
tab _merge year
drop if _merge==2
drop _merge
* 2014's variables
merge m:1 folio yearEFH  using "$path\dta\Rouding_INR\variables_2014.dta"  ,replace update 
tab _merge year
drop if _merge==2
drop _merge
* 2017's variables
merge m:1 folio yearEFH  using "$path\dta\Rouding_INR\variables_2017.dta"   ,replace update 
tab _merge year
drop if _merge==2
drop _merge
* Time elapsed
rename  yearEFH year_efh
merge m:1 folio year_efh  using "$path\dta\base_time_elapsed_wide.dta"
tab _merge year
drop if _merge==2
drop _merge
rename year_efh yearEFH
*------------------
* Rounding and use of brackets: 2011
merge m:1 folio yearEFH  using "$path\dta\Rouding_INR\ro_2011.dta" 
tab _merge year
drop if _merge==2
drop _merge
* Rounding and use of brackets: 2014
merge m:1 folio yearEFH  using "$path\dta\Rouding_INR\ro_2014.dta"  ,replace update  
tab _merge year
drop if _merge==2
drop _merge
* Rounding and use of brackets: 2017
merge m:1 folio yearEFH  using "$path\dta\Rouding_INR\ro_2017.dta"  ,replace update  
tab _merge year
drop if _merge==2
drop _merge


***************************************************************************************
* Variables explicativas
***************************************************************************************
gen edad2=edad*edad
gen edad_d=int(edad/10)
label var edad_d "Age (in decades)"
g edadsq=edad_d*edad_d
label var edadsq "Age (in decades) squared"
gen terc_educ=(neduc>3)
label var terc_educ "Interviewed holds a post-secondary degree"
gen relationship =(est_civ==2)
label var relationship "In a relationship"
gen sobr_end=(perc_end==1|perc_end==2)
label var sobr_end "Household feels over-indebted"
gen       int_knowledge=(x_n3==3)
label var int_knowledge   "Good knowledge of the interviewed"
gen       int_disposition=(x_n5==3)
label var int_disposition "Good disposition of the interviewed"
g c6_act_indef2=c6_act_indef 
recode c6_act_indef2 2=1 7=1 4=3 6=3
lab def c6_act_indef2 1 "Self-employed" 3 "Civil servant" 5 "Private sector" 8 "Inactive or unemployed" 9 "Pensioner", modify
label values c6_act_indef2 c6_act_indef2
label var c6_act_indef2 "Occupational status"
gen n_cconhip=n_ccon+n_chip
label var n_cconhip "Number of loans"
gen p_estrato3   =(estrato==3)
label var p_estrato3 "If household belongs to highest 2 deciles"
/* Not working here
gen tipo_d=(tipo==9)
label var tipo_d "Type of banking debt"
lab def tipo_d 0 "Installment loan" 1 "Mortgage loan" , modify
label values tipo_d tipo_d
*/
gen education=1 if neduc==1 | neduc==2
replace education=2 if neduc==3
replace education=3 if neduc==4
replace education=4 if neduc==5
label var education "Education"
lab def education 1 "Only school" 2 "Technical education" 3 "University" 4 "Postgraduate" , modify
label values education education

gen male_nmarried=(genero==1 & married==0)
label var male_nmarried "Male, not married"
/*bys folio yearEFH: egen atr_12m_h=max(atr_12m)
label var atr_12m_h "Interviewed has had credit arrears in last 12 months"
*/

******************************************
* Time elapsed variable
******************************************
de max_elapsed_5 prom_elapsed_s_5 prom_elapsed_p_5 max_elapsed_9 prom_elapsed_s_9 prom_elapsed_p_9
foreach u in max_elapsed prom_elapsed_s prom_elapsed_p {
gen `u'=`u'_5 if tipo_deuda==3
replace `u'=`u'_9 if tipo_deuda==1
}

*****************************************
* Number of consumer and mortgage credits
*****************************************
egen  n_credits=rownonmiss(t_m_td5_*) if tipo_deuda==3
egen  n_creditsv2=rownonmiss(t_m_td9_*)  
replace n_credits=n_creditsv2  if tipo_deuda==1 
drop n_creditsv2

*****************************************
* Rounding
*****************************************
gen     rounding_m=ro_m_td5 if tipo_deuda==3
replace rounding_m=ro_m_td9 if tipo_deuda==1
replace rounding_m=ro_m_td1 if tipo_deuda==4
replace rounding_m=ro_m_td2 if tipo_deuda==2
*---
gen     rounding_cf=ro_cf_td5 if tipo_deuda==3
replace rounding_cf=ro_cf_td9 if tipo_deuda==1
replace rounding_cf=ro_cf_td1 if tipo_deuda==4
replace rounding_cf=ro_cf_td2 if tipo_deuda==2
*---
gen     brackets_m=t_m_td5 if tipo_deuda==3
replace brackets_m=t_m_td9 if tipo_deuda==1
replace brackets_m=t_m_td1 if tipo_deuda==4
replace brackets_m=t_m_td2 if tipo_deuda==2
*---
gen     brackets_cf=t_cf_td5 if tipo_deuda==3
replace brackets_cf=t_cf_td9 if tipo_deuda==1
replace brackets_cf=t_cf_td1 if tipo_deuda==4
replace brackets_cf=t_cf_td2 if tipo_deuda==2
*---

*****************************************
* Ortogonal Rounding (only mortgages and consumer loans)
*****************************************
gen     orounding_m =ro_m_td9 if tipo_deuda==3
replace orounding_m =ro_m_td5 if tipo_deuda==1
*---
gen     orounding_cf=ro_cf_td9 if tipo_deuda==3
replace orounding_cf=ro_cf_td5 if tipo_deuda==1
*---
replace orounding_m=0 if orounding_m==.
replace orounding_cf=0 if orounding_cf==.


*****************************************
* Ortogonal Brackets (only mortgages and consumer loans)
*****************************************
gen     obrackets_m =t_m_td9 if tipo_deuda==3
replace obrackets_m =t_m_td5 if tipo_deuda==1
*---
gen     obrackets_cf=t_cf_td9 if tipo_deuda==3
replace obrackets_cf=t_cf_td5 if tipo_deuda==1
*---
replace obrackets_m=0 if obrackets_m==.
replace obrackets_cf=0 if obrackets_cf==.

***************************************************************************************
* Globals and additional variable definiions
***************************************************************************************
egen id=group(folio yearEFH)

/*global explic_var1 "male_nmarried married i.education edad_d edadsq"             
global explic_var2 "male_nmarried married i.education edad edad2"             
global explic_var3 " married i.education edad_d edadsq i.c6_act_indef2 i.genero"             
global explic_var4 " married i.education edad edad2 i.c6_act_indef2 i.genero i.estrato i.macrozona"             
global explic_var5 " married i.education edad edad2 i.c6_act_indef2 i.genero i.macrozona "             */
global explic_var6 " married i.education edad edad2 i.c6_act_indef2 i.genero i.refresco i.macrozona i.weekend i.yearEFH ib2.tipo_deuda "             

*------
/*global adicional   "numh i.n_encuestados n_ing n_cconhip d_transf i.macrozona refresco jefe_hog i.yearEFH"
global adicional2  "numh i.n_encuestados n_cconhip n_ingact gen_ing d_transf i.macrozona refresco i.yearEFH"
global adicional3  "numh n_cconhip n_ingact gen_ing d_transf i.macrozona "
global adicional4  "numh n_cconhip n_ing n_act gen_ing d_transf i.refresco i.yearEFH"
global adicional5 "numh n_cconhip n_ingact gen_ing d_transf i.refresco "
global adicional6 "numh n_cconhip n_ingact gen_ing d_transf i.refresco i.tipo_deudar"
global adicional7 "n_act gen_ing d_transf i.refresco ib2.tipo_deudar"
global adicional8 "n_act d_transf gen_ing i.refresco "
global adicional9 "i.refresco"
*global adicional9 "n_ingact i.refresco i.yearEFH" 
global adicional10 "d_nomax_ing i.refresco i.yearEFH"
global adicional11 "gen_ing i.refresco i.yearEFH "
global adicional12 "a1_nothighest_income i.refresco i.yearEFH "  */

* Proportional error definition
g E_error_ratio0 = 100*abs(error_ratio0) if error_ratio0>=-2 & error_ratio0<=2  //make them in %
g E_error_ratio0R = 100*abs(error_ratio0R) if error_ratio0R>=-2 & error_ratio0R<=2  //make them in %; rounding error

* Debt types
g tipo_deudar=tipo_deuda
replace tipo_deudar = 2 if (tipo_deuda == 2| tipo_deuda == 4)
lab def tipo_deudar 1 "Mortgages" 2 "Credit card and lines" 3 "Installment loans" , modify
label values tipo_deudar tipo_deudar

* TL to the logit 
replace error_EFH_notSBIF=0 if ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==1) ///
& tipo_deuda==2) | ((deuda_linea_EFH==1 & deuda_linea_SBIF==1) & tipo_deuda==4)

replace error_EFH_notSBIF=1 if ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==0) ///
& tipo_deuda==2) | ((deuda_linea_EFH==1 & deuda_linea_SBIF==0) & tipo_deuda==4)


* Error not EFH and yes SBIF
g error_notEFH_SBIF=.
replace error_notEFH_SBIF=0 if ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==1) & tipo_deuda==2) | ///
((deuda_linea_EFH==1 & deuda_linea_SBIF==1) & tipo_deuda==4)  | ///
((deuda_hipotecario_EFH==1 & deuda_hipotecario_SBIF==1) & tipo_deuda==1) | ///
((deuda_prestamo_EFH==1 & deuda_prestamo_SBIF==1) & tipo_deuda==3) 

replace error_notEFH_SBIF=1 if ((deuda_tarjeta_EFH==0 & deuda_tarjeta_SBIF==1) & tipo_deuda==2) | ///
((deuda_linea_EFH==0 & deuda_linea_SBIF==1) & tipo_deuda==4) | ///
((deuda_hipotecario_EFH==0 & deuda_hipotecario_SBIF==1) & tipo_deuda==1) | ///
((deuda_prestamo_EFH==0 & deuda_prestamo_SBIF==1) & tipo_deuda==3) 
   
* Error  EFH and not SBIF
g error_EFH_notSBIF_v2=.
replace error_EFH_notSBIF_v2=0 if ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==1) & tipo_deuda==2) | ///
((deuda_linea_EFH==1 & deuda_linea_SBIF==1) & tipo_deuda==4)  | ///
((deuda_hipotecario_EFH==1 & deuda_hipotecario_SBIF==1) & tipo_deuda==1) | ///
((deuda_prestamo_EFH==1 & deuda_prestamo_SBIF==1) & tipo_deuda==3) 

replace error_EFH_notSBIF_v2=1 if ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==0) & tipo_deuda==2) | ///
((deuda_linea_EFH==1 & deuda_linea_SBIF==0) & tipo_deuda==4) | ///
((deuda_hipotecario_EFH==1 & deuda_hipotecario_SBIF==0) & tipo_deuda==1) | ///
((deuda_prestamo_EFH==1 & deuda_prestamo_SBIF==0) & tipo_deuda==3) 
   
g tarj_lin=0
replace tarj_lin=1 if  (tipo_deuda==2 | tipo_deuda==4)

g tipo_deudat=1
replace tipo_deudat=2 if  (tipo_deuda==2 | tipo_deuda==4)
replace tipo_deudat=3 if  tipo_deuda==3

** Additional variables
* Split variable conoc_fondo: i) if interviewee responds the question about pension fund
* ii) interviewee knows the amount of his pension fund

g resp_fondo=(conoc_fondo<2)
lab def resp_fondo 0 "Does not apply" 1 "Int. responds about pension fund"
lab val resp_fondo resp_fondo

g sabe_fondo=(conoc_fondo==1)
lab def sabe_fondo 0 "Int. does not know" 1 "Int. knows"
lab val sabe_fondo sabe_fondo

g weekend=(dow==6 | dow==7)
lab def weekend 0 "Int. working days" 1 "Int. weekend"
lab val weekend weekend

g dispo_dum=0
replace dispo_dum=1 if x_n5==3
lab def dispo_dum 0 "Is not good" 1 "Int. dispo is good"
lab val dispo_dum dispo_dum


*****************************************************
*If have consumer loans and mortgage at the same time
*****************************************************
*bys folio yearEFH: egen count=count(rounding_m) if tipo_deuda==1 | tipo_deuda==3
bys folio yearEFH: egen count=count(E_error_ratio0) if tipo_deuda==1 | tipo_deuda==3
gen both_loans=(count==2) if count!=0 & (tipo_deuda==1 | tipo_deuda==3)
*br folio yearEFH tipo_* rounding_m count both_loans if   tipo_deudat!=2

*********************************************************
*If have other loans different than consumer and mortgage
*********************************************************
gen     no_cons_mort_cf=(ro_cf_td_no5_9!=.)
replace ro_cf_td_no5_9=0 if ro_cf_td_no5_9==.
*---
gen     no_cons_mort_m=(ro_m_td_no5_9!=.)
replace ro_m_td_no5_9=0 if ro_m_td_no5_9==.

***************************************************************************************
* Regressions with debt ownership status (EFH=1,SBIF=0)
***************************************************************************************
/*cd "$path\tablas"
global path "$path\tablas\2020"
cd "C:\Users\pmargaretic\Dropbox\Cruce\Paper descriptivo\Stata\tablas\2020"
*/
cd "$path/tablas/2020/regressions"


***************************************************************************************
* Comparison of regressions for the two debt ownership error (EFH=0,SBIF=1) & (EFH=1,SBIF=0) (without 2011)
***************************************************************************************
global explic_var6 " married i.education edad edad2 i.c6_act_indef2 i.genero i.refresco i.macrozona i.weekend "             
*global adicional11 "i.a1_nothighest_income##ib3.tipo_deuda i.yearEFH"
global adicional11 "i.a1_nothighest_income##ib3.tipo_deudat i.yearEFH"

* (EFH=1,SBIF=0)
* we have a problem in the dependent variable error_EFH_notSBIF since in dep_var=0 there are
* some obs with EFH=1 and SBIF=.  (128 obs), but these observations should be missing or 1, but
* not zero.
 

 
 
***************************************************************************************
* Comparison results including error=2,-2 and excluding them (LOAN AMOUNTS)
***************************************************************************************
* We keep only consumer and mortgage loans
drop if tipo_deudat==2

***********************************************************************************************
* Variables to check
de n_chip n_ccon refresco x_n3 x_n5 n_seg_e uso_docs n_encuestados perc_end camb_dom d_nomax_edad
de max_elapsed prom_elapsed_s prom_elapsed_p 
***********************************************************************************************

g ratio2= (error_ratio0==2)       
g ratio_2= (error_ratio0==-2)       
global explic_var6 " married i.education edad edad2 i.c6_act_indef2 i.genero i.refresco i.macrozona i.weekend i.yearEFH ib3.tipo_deudat "    
*global explic_var7  "miss_ing round_ingact i.dispo_dum i.resp_fondo##i.sabe_fondo"
global explic_var7   "i.dispo_dum   miss_ing   i.resp_fondo##i.sabe_fondo"
*round_ingact n_act

/*
*Total
set more off 
reg E_error_ratio0 $explic_var6 $explic_var7                   if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_rou.xls" , replace ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7 max_elapsed        if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_rou.xls" , append ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7             i.both_loans#c.orounding_m if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_rou.xls" , append ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7             i.both_loans#c.orounding_cf if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_rou.xls" , append ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7 max_elapsed i.both_loans#c.orounding_m if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_rou.xls" , append ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7 max_elapsed rounding_cf if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_rou.xls" , append ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7             rounding_cf if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)   , vce(cluster id) 
outreg2 using "Regressions_rou.xls" , append ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7 max_elapsed rounding_cf brackets_cf if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_rou.xls" , append ctitle(fondo)  dec(3) 
*----
*/

*Total v2
set more off 
reg E_error_ratio0 $explic_var6 $explic_var7 round_ingact                   if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_rou_v2.xls" , replace ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7 round_ingact max_elapsed        if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_rou_v2.xls" , append ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7 round_ingact             i.no_cons_mort_m#c.ro_m_td_no5_9 if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_rou_v2.xls" , append ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7 round_ingact             i.no_cons_mort_cf#c.ro_cf_td_no5_9 if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_rou_v2.xls" , append ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7 round_ingact max_elapsed i.no_cons_mort_m#c.ro_m_td_no5_9 if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_rou_v2.xls" , append ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7 round_ingact max_elapsed i.no_cons_mort_cf#c.ro_cf_td_no5_9 if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_rou_v2.xls" , append ctitle(fondo)  dec(3) 
*----


*Total v3
set more off 
reg E_error_ratio0 $explic_var6 $explic_var7 round_ingact                  if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_rou_v3.xls" , replace ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7 round_ingact max_elapsed        if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_rou_v3.xls" , append ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7 round_ingact             i.both_loans#c.orounding_m if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_rou_v3.xls" , append ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7 round_ingact            i.both_loans#c.orounding_cf if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_rou_v3.xls" , append ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7 round_ingact max_elapsed i.both_loans#c.orounding_m if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_rou_v3.xls" , append ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7 round_ingact max_elapsed rounding_cf if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_rou_v3.xls" , append ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7 round_ingact            rounding_cf if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)   , vce(cluster id) 
outreg2 using "Regressions_rou_v3.xls" , append ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7 round_ingact max_elapsed rounding_cf brackets_cf if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_rou_v3.xls" , append ctitle(fondo)  dec(3) 
*----






* Corr rounding
corr rounding_cf rounding_m
reg E_error_ratio0 $explic_var6 $explic_var7 max_elapsed rounding_cf if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
corr rounding_cf rounding_m if e(sample)



/*
* Sin 2011
reg E_error_ratio0 $explic_var6 $explic_var7 max_elapsed rounding_cf i.uso_docs    if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_no2011.xls" , replace ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7 max_elapsed rounding_cf   i.n_encuestados  if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_no2011.xls" , append ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7 max_elapsed rounding_cf   i.camb_dom  if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_no2011.xls" , append ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7 max_elapsed rounding_cf i.uso_docs  i.n_encuestados i.camb_dom  if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_no2011.xls" , append ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7 max_elapsed rounding_cf  i.experiencia_enc  if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_no2011.xls" , append ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7 max_elapsed rounding_cf   i.neduc_enc   if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_no2011.xls" , append ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7 max_elapsed rounding_cf   i.genero_enc   if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_no2011.xls" , append ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7 max_elapsed rounding_cf   edad_enc   if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_no2011.xls" , append ctitle(fondo)  dec(3) 
*----
reg E_error_ratio0 $explic_var6 $explic_var7 max_elapsed rounding_cf  i.experiencia_enc i.neduc_enc i.genero_enc edad_enc if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , vce(cluster id) 
outreg2 using "Regressions_no2011.xls" , append ctitle(fondo)  dec(3) 
*----





