*************************************************************************************
* Extensive margin analysis
*************************************************************************************

* Base regresiones
global path "C:\Users\pedro\Dropbox\Cruce\Paper descriptivo\Stata"
use "$path/dta/analysis11_14_17_vfix_long.dta", clear

***************************************************************************************
* Variables explicativas
***************************************************************************************
gen edad2=edad*edad
gen edad_d=int(edad/10)
label var edad_d "Age (in decades)"
g edadsq=edad_d*edad_d
label var edadsq "Age (in decades) squared"
gen terc_educ=(neduc>3)
label var terc_educ "Interviewed holds a post-secondary degree"
gen relationship =(est_civ==2)
label var relationship "In a relationship"
gen sobr_end=(perc_end==1|perc_end==2)
label var sobr_end "Household feels over-indebted"
gen       int_knowledge=(x_n3==3)
label var int_knowledge   "Good knowledge of the interviewed"
gen       int_disposition=(x_n5==3)
label var int_disposition "Good disposition of the interviewed"
g c6_act_indef2=c6_act_indef 
recode c6_act_indef2 2=1 7=1 4=3 6=3
lab def c6_act_indef2 1 "Self-employed" 3 "Civil servant" 5 "Private sector" 8 "Inactive or unemployed" 9 "Pensioner", modify
label values c6_act_indef2 c6_act_indef2
label var c6_act_indef2 "Occupational status"
gen n_cconhip=n_ccon+n_chip
label var n_cconhip "Number of loans"
gen p_estrato3   =(estrato==3)
label var p_estrato3 "If household belongs to highest 2 deciles"
gen education=1 if neduc==1 | neduc==2
replace education=2 if neduc==3
replace education=3 if neduc==4
replace education=4 if neduc==5
label var education "Education"
lab def education 1 "Only school" 2 "Technical education" 3 "University" 4 "Postgraduate" , modify
label values education education
gen male_nmarried=(genero==1 & married==0)
label var male_nmarried "Male, not married"

***************************************************************************************
* Globals and additional variable definiions
***************************************************************************************
egen id=group(folio yearEFH)

global explic_var6 " married i.education edad edad2 i.c6_act_indef2 i.genero i.refresco i.macrozona i.weekend i.yearEFH ib2.tipo_deuda "             

* Proportional error definition
g E_error_ratio0 = 100*abs(error_ratio0) if error_ratio0>=-2 & error_ratio0<=2  //make them in %
g E_error_ratio0R = 100*abs(error_ratio0R) if error_ratio0R>=-2 & error_ratio0R<=2  //make them in %; rounding error

* Debt types
g tipo_deudar=tipo_deuda
replace tipo_deudar = 2 if (tipo_deuda == 2| tipo_deuda == 4)
lab def tipo_deudar 1 "Mortgages" 2 "Credit card and lines" 3 "Installment loans" , modify
label values tipo_deudar tipo_deudar

* TL to the logit 
replace error_EFH_notSBIF=0 if ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==1) ///
& tipo_deuda==2) | ((deuda_linea_EFH==1 & deuda_linea_SBIF==1) & tipo_deuda==4)

replace error_EFH_notSBIF=1 if ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==0) ///
& tipo_deuda==2) | ((deuda_linea_EFH==1 & deuda_linea_SBIF==0) & tipo_deuda==4)

* Error not EFH and yes SBIF
g error_notEFH_SBIF=.
replace error_notEFH_SBIF=0 if ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==1) & tipo_deuda==2) | ///
((deuda_linea_EFH==1 & deuda_linea_SBIF==1) & tipo_deuda==4)  | ///
((deuda_hipotecario_EFH==1 & deuda_hipotecario_SBIF==1) & tipo_deuda==1) | ///
((deuda_prestamo_EFH==1 & deuda_prestamo_SBIF==1) & tipo_deuda==3) 

replace error_notEFH_SBIF=1 if ((deuda_tarjeta_EFH==0 & deuda_tarjeta_SBIF==1) & tipo_deuda==2) | ///
((deuda_linea_EFH==0 & deuda_linea_SBIF==1) & tipo_deuda==4) | ///
((deuda_hipotecario_EFH==0 & deuda_hipotecario_SBIF==1) & tipo_deuda==1) | ///
((deuda_prestamo_EFH==0 & deuda_prestamo_SBIF==1) & tipo_deuda==3) 
   
* Error  EFH and not SBIF
g error_EFH_notSBIF_v2=.
replace error_EFH_notSBIF_v2=0 if ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==1) & tipo_deuda==2) | ///
((deuda_linea_EFH==1 & deuda_linea_SBIF==1) & tipo_deuda==4)  | ///
((deuda_hipotecario_EFH==1 & deuda_hipotecario_SBIF==1) & tipo_deuda==1) | ///
((deuda_prestamo_EFH==1 & deuda_prestamo_SBIF==1) & tipo_deuda==3) 

replace error_EFH_notSBIF_v2=1 if ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==0) & tipo_deuda==2) | ///
((deuda_linea_EFH==1 & deuda_linea_SBIF==0) & tipo_deuda==4) | ///
((deuda_hipotecario_EFH==1 & deuda_hipotecario_SBIF==0) & tipo_deuda==1) | ///
((deuda_prestamo_EFH==1 & deuda_prestamo_SBIF==0) & tipo_deuda==3) 
   
g tarj_lin=0
replace tarj_lin=1 if  (tipo_deuda==2 | tipo_deuda==4)

g tipo_deudat=1
replace tipo_deudat=2 if  (tipo_deuda==2 | tipo_deuda==4)
replace tipo_deudat=3 if  tipo_deuda==3

** Additional variables
* Split variable conoc_fondo: i) if interviewee responds the question about pension fund
* ii) interviewee knows the amount of his pension fund

g resp_fondo=(conoc_fondo<2)
lab def resp_fondo 0 "Does not apply" 1 "Int. responds about pension fund"
lab val resp_fondo resp_fondo

g sabe_fondo=(conoc_fondo==1)
lab def sabe_fondo 0 "Int. does not know" 1 "Int. knows"
lab val sabe_fondo sabe_fondo

g weekend=(dow==6 | dow==7)
lab def weekend 0 "Int. working days" 1 "Int. weekend"
lab val weekend weekend

g dispo_dum=0
replace dispo_dum=1 if x_n5==3
lab def dispo_dum 0 "Is not good" 1 "Int. dispo is good"
lab val dispo_dum dispo_dum


********************************************************************************
* Analysis of the error EFH-SBIF variables
********************************************************************************
egen maxEFH_SBIF=rmax(deuda_hipotecario_* deuda_tarjeta_* deuda_linea_* deuda_prestamo_*)

br folio yearEFH tipo_deuda error_EFH_notSBIF error_notEFH_SBIF deuda_hipotecario_* deuda_tarjeta_* deuda_linea_* deuda_prestamo_*

table error_EFH_notSBIF deuda_hipotecario_*  if tipo_deuda==1
table error_EFH_notSBIF deuda_tarjeta_*  if tipo_deuda==4
table error_EFH_notSBIF deuda_linea_*  if tipo_deuda==2
table error_EFH_notSBIF deuda_prestamo_*  if tipo_deuda==3

tab error_EFH_notSBIF deuda_tarjeta_EFH  if tipo_deuda==4 ,miss

br folio yearEFH tipo_deuda error_EFH_notSBIF deuda_tarjeta_*  if error_EFH_notSBIF==. & (deuda_tarjeta_EFH==1 | deuda_tarjeta_SBIF==1) & tipo_deuda==4
br folio yearEFH tipo_deuda error_EFH_notSBIF error_notEFH_SBIF deuda_linea_*  if error_EFH_notSBIF==. & (deuda_linea_EFH==1 | deuda_linea_SBIF==1) & tipo_deuda==2
br folio yearEFH tipo_deuda error_EFH_notSBIF error_notEFH_SBIF deuda_hipotecario_*  if error_EFH_notSBIF==. & (deuda_hipotecario_EFH==1 | deuda_hipotecario_SBIF==1) & tipo_deuda==1
br folio yearEFH tipo_deuda error_EFH_notSBIF error_notEFH_SBIF deuda_prestamo_*  if error_EFH_notSBIF==. & (deuda_prestamo_EFH==1 | deuda_prestamo_SBIF==1) & tipo_deuda==3



/*

***************************************************************************************
* Regressions with debt ownership status 
***************************************************************************************

cd "$path/tablas/2020/Margen_extensivo"

/* to do: Check the dependent variable. 2) do estimations with and then without FE */

* 2020 07: All debt types together (EFH=1,SBIF=0) in the current version of the paper. However, not exactly the same
***************************************************************************************
global explic_var " married i.education edad edad2 i.c6_act_indef2 i.genero i.refresco i.macrozona i.weekend "             
global explic_var2 " married  edad edad2 i.c6_act_indef2 i.genero i.refresco i.macrozona i.weekend "             
global adicional1 "i.a1_nothighest_income##ib3.tipo_deudat i.dispo_dum i.refresco i.yearEFH"
global adicional2 "i.a1_nothighest_income##ib3.tipo_deudat i.dispo_dum i.a1_nothighest_income##i.sabe_fondo i.refresco i.yearEFH"
global adicional3 "i.a1_nothighest_income##ib3.tipo_deudat i.dispo_dum##i.sabe_fondo i.refresco i.yearEFH"
global adicional4 "i.a1_nothighest_income##ib3.tipo_deudat i.a1_nothighest_income##i.sabe_fondo i.dispo_dum##i.sabe_fondo i.refresco i.yearEFH"
global adicional5 "i.a1_nothighest_income##ib3.tipo_deudat i.dispo_dum i.a1_nothighest_income##i.sof_fin i.refresco i.yearEFH"


* Alternative specifications with interactions

* With interaction between i.resp_fondo##i.sabe_fondo and with FE
set more off
logit error_EFH_notSBIF $explic_var $adicional1 i.resp_fondo##i.sabe_fondo  miss_ing  round_ingact  if reporut_2017!=0 [pw=factor_egm], vce(cluster id)




table error_EFH_notSBIF deuda_hipotecario_*  if tipo_deuda==1
table error_EFH_notSBIF deuda_tarjeta_*  if tipo_deuda==4
table error_EFH_notSBIF deuda_linea_*  if tipo_deuda==2
table error_EFH_notSBIF deuda_prestamo_*  if tipo_deuda==3



/*
egen maxEFH_SBIF=rmax(deuda_hipotecario_* deuda_tarjeta_* deuda_linea_* deuda_prestamo_*)

br folio yearEFH tipo_deuda error_EFH_notSBIF error_EFH_notSBIF_v2 error_notEFH_SBIF deuda_hipotecario_* deuda_tarjeta_* deuda_linea_* deuda_prestamo_*
