********************************************************
* Mean comparisons table 
********************************************************

set more off
clear
global path "C:\Users\pedro\Dropbox"


*---------
* EFH 2017
*---------
use "$path\Cruce\Paper descriptivo\Stata\efh_dta\EFH_17_allvars.dta", clear
keep if ord==1
sum genero educ edad estado_civ macrozona estrato

*******************************************************************************************************
*----------------------------------------------------
*----------------------------------------------------
*------------------ Solo EFH 2017 ------------------*
* Quien es titular de la deuda hipotecaria
gen e14=min(e14_1, e14_2, e14_3)
forv i=1/3 {
gen e56_`i'=min(e56_1_`i', e56_2_`i', e56_3_`i')
}
drop e14_* e56_*_*
*----------------------------------------------------
*----------------------------------------------------
forv k=1/8 {
forv m=1/3 {
rename f3_t`k'd`m' f3_td`k'_`m'
}
}
rename f3_t3d4 f3_td3_4
* Renombramiento variables hipotecarias
drop cf_td9_*
rename div_chvp cf_td9_1
* Créditos complementarios como consumo bancario
rename div_ocvp cf_td5_4
g f3_td5_4=1 if cf_td5_4>0
forv k=1/3 {
* Créditos hipotecarios como deuda 9
local m=`k'+1
rename div_chotp_`k' cf_td9_`m'
* Créditos complementarios como de consumo bancario
local p=`k'+4
rename div_ocotp_`k' cf_td5_`p'
g f3_td5_`p'=1 if cf_td5_`p'>0
rename pp_m_ocotp_`k' pp_td5_`p'
}
* Deudor de la deuda hipotecaria (solo en EFH 2017)
rename (e14 e56_1 e56_2 e56_3) (e14_1 e14_2 e14_3 e14_4)
forv k=1/4 {
g f3_td9_`k'=e14_`k' if cf_td9_`k'>0
}
drop e14_*
*******************************************************************************************************


* Hombre
gen man=(genero==1)

* Casado
gen married=(a6==1)

* Macrozona
gen north=(macrozona==1)
gen center=(macrozona==2)
gen south=(macrozona==3)
gen rm=(macrozona==4)

* Estrato
gen estrato1=(estrato==1)
gen estrato2=(estrato==2)
gen estrato3=(estrato==3)

* Conoce fondo AFP
drop conoc_fondo
gen conoc_fondo=(i14==1 & i15_1<8 & i15_2<8 & i15_3<8 & i15_4<8 & i15_5<8) if i14!=.
replace conoc_fondo=2 if conoc_fondo==. 
*----------------------
g fondo_afp=0
replace fondo_afp=1 if conoc_fondo==1 /*knows the fund*/
replace fondo_afp=2 if conoc_fondo==0 /*does not know*/
lab def fondo_afp 0 "Does not apply" 1 "Int. knows about pension fund" 2 "Int. does not know"
gen nofondo=(fondo_afp==0)
gen conocfondo=(fondo_afp==1)
gen noconocfondo=(fondo_afp==2)

* Uso de PAT y PAC
gen sof_fin=(u_pat==1 | u_pac==1) 
tab sof_fin if ord==1 ,miss

* Concimiento y disposición de los entrevidados
foreach u in n3 n5 {
gen x_`u'=0
replace x_`u'=1 if `u'<4
replace x_`u'=2 if `u'>=4 & `u'<=7 
replace x_`u'=3 if `u'>7
lab val x_`u' x_`u'_1
}
*-----------------------
g dispo_dum=0
replace dispo_dum=1 if x_n5==3
lab def dispo_dum 0 "Is not good" 1 "Int. dispo is good"
lab val dispo_dum dispo_dum

* Tenencia
egen min_tyl    =rowmin(f3_td1_* f3_td2_*)
gen  tyl        =(min_tyl==1)
egen  min_pbanc  =rowmin(f3_td5_*)
gen  pbanc      =(min_pbanc==1)
egen  min_chip   =rowmin(f3_td9_*)
gen  chip       =(min_chip==1)

* Dejamos lo que nos interesa
gen year_efh=2017
order folio year_efh 
keep folio year_efh man educ edad married north center south rm estrato1 estrato2 estrato3 /*
*/ nofondo conocfondo noconocfondo sof_fin dispo_dum tyl pbanc chip

tempfile efh_17
save `efh_17'



****************************************************************************************************************
****************************************************************************************************************
****************************************************************************************************************



*---------
* EFH 2014
*---------
use "$path\Cruce\Paper descriptivo\Stata\efh_dta\EFH_14_allvars.dta", clear
keep if ord==1

********************************************************************************************************
* Union modulos mno EFH 2014
rename folio folio_2014
joinby folio_2014 using "$path\Cruce\Paper descriptivo\Stata\efh_dta\bcch_efh2014_hogares_modulos_mno_.dta", unm(b)
tab _merge
drop if _merge==2
drop _merge
rename  folio_2014 folio

forv k=1/8 {
forv m=1/3 {
rename f3_t`k'd`m' f3_td`k'_`m'
}
}
rename f3_t3d4 f3_td3_4
* Renombramiento variables hipotecarias
rename d_chvp d_td9_1
rename div_chvp cf_td9_1
* Créditos complementarios como consumo bancario
rename d_ccvp d_td5_4
rename div_ccvp cf_td5_4
g f3_td5_4=1 if cf_td5_4>0
forv k=1/3 {
* Créditos hipotecarios como deuda 9
local m=`k'+1
rename div_chotp_`k' cf_td9_`m'
* Créditos complementarios como de consumo bancario
local p=`k'+4
rename div_ccotp_`k' cf_td5_`p'
g f3_td5_`p'=1 if cf_td5_`p'>0
rename pp_m_ccotp_`k' pp_td5_`p'
}
* Entrevistado como dueño de la deuda hipotecaria
forv k=1/4 {
g f3_td9_`k'=1 if cf_td9_`k'>0
}
********************************************************************************************************

* Hombre
gen man=(genero==1)

* Casado
gen married=(a5==1)

* Macrozona
gen north=(macrozona==1)
gen center=(macrozona==2)
gen south=(macrozona==4)
gen rm=(macrozona==3)

* Estrato
gen estrato1=(estrato==1)
gen estrato2=(estrato==2)
gen estrato3=(estrato==3)

* Conoce fondo AFP
capture: drop conoc_fondo
gen conoc_fondo=(i13==1 & i14_1<8 & i14_2<8 & i14_3<8 & i14_4<8 & i14_5<8) if i13!=.
replace conoc_fondo=2 if conoc_fondo==. 
*----------------------
g fondo_afp=0
replace fondo_afp=1 if conoc_fondo==1 /*knows the fund*/
replace fondo_afp=2 if conoc_fondo==0 /*does not know*/
lab def fondo_afp 0 "Does not apply" 1 "Int. knows about pension fund" 2 "Int. does not know"
gen nofondo=(fondo_afp==0)
gen conocfondo=(fondo_afp==1)
gen noconocfondo=(fondo_afp==2)

* Uso de PAT y PAC
gen sof_fin=(u_pat==1 | u_pac==1) 

* Concimiento y disposición de los entrevidados
foreach u in n3 n5 {
gen x_`u'=0
replace x_`u'=1 if `u'<4
replace x_`u'=2 if `u'>=4 & `u'<=7 
replace x_`u'=3 if `u'>7
lab val x_`u' x_`u'_1
}
*-----------------------
g dispo_dum=0
replace dispo_dum=1 if x_n5==3
lab def dispo_dum 0 "Is not good" 1 "Int. dispo is good"
lab val dispo_dum dispo_dum

* Tenencia
egen min_tyl    =rowmin(f3_td1_* f3_td2_*)
gen  tyl        =(min_tyl==1)
egen  min_pbanc  =rowmin(f3_td5_*)
gen  pbanc      =(min_pbanc==1)
egen  min_chip   =rowmin(f3_td9_*)
gen  chip       =(min_chip==1)

* Dejamos lo que nos interesa
gen year_efh=2014
order folio year_efh 
keep folio year_efh man educ edad married north center south rm estrato1 estrato2 estrato3 /*
*/ nofondo conocfondo noconocfondo sof_fin dispo_dum tyl pbanc chip

tempfile efh_14
save `efh_14'



****************************************************************************************************************
****************************************************************************************************************
****************************************************************************************************************


*---------
* EFH 2011
*---------
use "$path\Cruce\Paper descriptivo\Stata\efh_dta\EFH_11_allvars.dta", clear
keep if ord==1

********************************************************************************************************
* Cargas financieras consumo
rename cf_1_td*              cf_td*_1 
rename cf_2_td*              cf_td*_2 
rename cf_3_td*              cf_td*_3 
rename cf_4_td*              cf_td*_4 
rename (cf_td4_* cf_td5_* cf_td6_* cf_td7_*) (cf_td5_* cf_td4_* cf_td7_* cf_td6_*)   // homologación deudas a efh 2014  
sum cf_td*_* ,d

* Dividendos hipotecarios
rename  div_m                div_chvp 
gen div_ccvp=0 // se asume 0
* otp
rename (div_m1 div_m2 div_m3) (div_chotp_1 div_chotp_2 div_chotp_3) 
drop  div_m_otp
sum div_chvp div_chotp_* ,d
* cc
forv i=1/3 {
gen div_ccotp_`i'=0 // se asume 0
}

* Titular de los créditos de consumo
rename (f3_t4d* f3_t5d* f3_t6d* f3_t7d*) (f3_t5d* f3_t4d* f3_t7d* f3_t6d*)
sum f3_t* ,d

*-----------------------------------------------------------------------
* Tramos se pasan a "."
*-----------------------------------------------------------------------

* Deuda residual y dividendo hipotecaria vp
replace div_chvp=. if e27_t<98 
* Deuda residual hipotecaria y dividendo otp
forv i=1/3 {
replace div_chotp_`i'=. if e54_t_`i'<98
}

* Creación de variables pensando en el reshape
forv k=1/8 {
forv m=1/3 {
rename f3_t`k'd`m' f3_td`k'_`m'
}
}
rename f3_t3d4 f3_td3_4
rename f4_t3d4 f4_td3_4
* Renombramiento variables hipotecarias
rename div_chvp cf_td9_1
* Créditos complementarios como consumo bancario
rename div_ccvp cf_td5_4
g f3_td5_4=1 if cf_td5_4>0
forv k=1/3 {
* Créditos hipotecarios como deuda 9
local m=`k'+1
rename div_chotp_`k' cf_td9_`m'
* Créditos complementarios como de consumo bancario
local p=`k'+4
rename div_ccotp_`k' cf_td5_`p'
g f3_td5_`p'=1 if cf_td5_`p'>0
}
* Entrevistado como dueño de la deuda hipotecaria
forv k=1/4 {
g f3_td9_`k'=1 if cf_td9_`k'>0
}


******************************************************************************************************

* Hombre
gen man=(sexo==1)

* Casado
gen married=(a7==1)

* Educacion
rename s educ

* Macrozona
gen north=(macrozona==1)
gen center=(macrozona==2)
gen south=(macrozona==3)
gen rm=(macrozona==4)

* Estrato
rename estrato_muestra estrato
gen estrato1=(estrato==1)
gen estrato2=(estrato==2)
gen estrato3=(estrato==3)

* Conoce fondo AFP
capture: drop conoc_fondo
gen conoc_fondo=((i9==2 & i10!="Y" & i10!="Z") | (i9==1 & i11!="Y" & i11!="Z")) if c24==1  // prima c24
replace conoc_fondo=2 if conoc_fondo==. 
*----------------------
g fondo_afp=0
replace fondo_afp=1 if conoc_fondo==1 /*knows the fund*/
replace fondo_afp=2 if conoc_fondo==0 /*does not know*/
lab def fondo_afp 0 "Does not apply" 1 "Int. knows about pension fund" 2 "Int. does not know"
gen nofondo=(fondo_afp==0)
gen conocfondo=(fondo_afp==1)
gen noconocfondo=(fondo_afp==2)

* Uso de PAT y PAC
gen sof_fin=(j3_6==1 & (t_cc==1 | j3_2==1 | j3_3==1)) 

* Concimiento y disposición de los entrevidados
rename (m1 m3) (n3 n5)
foreach u in n3 n5 {
gen x_`u'=0
replace x_`u'=1 if `u'<4
replace x_`u'=2 if `u'>=4 & `u'<=7 
replace x_`u'=3 if `u'>7
lab val x_`u' x_`u'_1
}
*-----------------------
g dispo_dum=0
replace dispo_dum=1 if x_n5==3
lab def dispo_dum 0 "Is not good" 1 "Int. dispo is good"
lab val dispo_dum dispo_dum

* Tenencia
egen min_tyl    =rowmin(f3_td1_* f3_td2_*)
gen  tyl        =(min_tyl==1)
egen  min_pbanc  =rowmin(f3_td5_*)
gen  pbanc      =(min_pbanc==1)
egen  min_chip   =rowmin(f3_td9_*)
gen  chip       =(min_chip==1)

* Dejamos lo que nos interesa
gen year_efh=2011
order folio year_efh 
keep folio year_efh man educ edad married north center south rm estrato1 estrato2 estrato3 /*
*/ nofondo conocfondo noconocfondo sof_fin dispo_dum tyl pbanc chip

tempfile efh_11
save `efh_11'



****************************************************************************************************************
****************************************************************************************************************
****************************************************************************************************************
****************************************************************************************************************
****************************************************************************************************************
****************************************************************************************************************


* Unimos las bases
set more off
clear
global path "C:\Users\pedro\Dropbox"
use  `efh_11'  , clear
append using `efh_14'
append using `efh_17'
order folio year_efh man educ edad married north center south rm estrato1 estrato2 estrato3 /*
*/ pbanc chip tyl dispo_dum nofondo conocfondo noconocfondo sof_fin 

* Merging with individuals who declare ID
merge 1:1 folio year_efh using "$path\Cruce\Paper descriptivo\Stata\dta\reporta_ruts_2011_2014_2017.dta"
tab _merge
gen with_id=(_merge==3)
drop _merge

* Merging with matched data
rename year_efh yearEFH
merge 1:1 folio yearEFH using "$path\Cruce\Paper descriptivo\Stata\dta\analysis11_14_17_vfix.dta" /*
*/ ,keepusing(deuda_hipotecario_SBIF deuda_prestamo_SBIF deuda_TL_SBIF deuda_hipotecario_EFH deuda_prestamo_EFH deuda_TL_EFH)
tab _merge
rename yearEFH year_efh
gen matched=(deuda_hipotecario_SBIF==1 | deuda_prestamo_SBIF==1 | deuda_TL_SBIF==1 )
drop _merge


* Stats
tabstat man - sof_fin                , s(mean semean) columns(statistics )
tabstat man - sof_fin  if with_id==1 , s(mean semean) columns(statistics )
tabstat man - sof_fin  if matched==1 , s(mean semean) columns(statistics )


