***************************************************************************************
* ANALISIS REGRESIONES INCLUYENDO EFECTOS FIJOS DE ENCUESTADORES
***************************************************************************************
*Uso creacion de bases de PR y especificaciones de FM

* Base regresiones
*global path "C:\Users\pedro\Dropbox\Cruce\Paper descriptivo\Stata"

*global path "C:\Users\pedro\Dropbox\Cruce\Paper descriptivo\Stata"
global path "C:\Users\felma.000\Dropbox\Cruce\Paper descriptivo\Stata"
use "$path/dta/analysis11_14_17_vfix_long.dta", replace

******************************************************
* Unimos bases
******************************************************
*joinby folio yearEFH tipo_deuda using "$path/dta/informacion_deudas.dta", unm(b)
joinby folio yearEFH tipo_deuda using "$path/dta/informacion_deudas.dta", unm(b)
tab _merge
rename _merge _merge1

* Household complexity variables
* 2011's variables
merge m:1 folio yearEFH  using "$path/dta/caract_hh_11.dta"  ,replace update 
tab _merge year
drop if _merge==2
drop _merge
* 2014's variables
merge m:1 folio yearEFH  using "$path/dta/caract_hh_14.dta"  ,replace update 
tab _merge year
drop if _merge==2
drop _merge
* 2017's variables
merge m:1 folio yearEFH  using "$path/dta/caract_hh_17.dta"   ,replace update 
tab _merge year
drop if _merge==2
drop _merge

*--------------------
* Interviewers' database (only 2014 & 2017)
merge m:1 folio yearEFH  using "$path/dta/base_enc_2014_2017.dta"
tab _merge year
drop if _merge==2
drop _merge
* 2014's variables
merge m:1 folio yearEFH  using "$path/dta/Rouding_INR/variables_2014.dta"  ,replace update 
tab _merge year
drop if _merge==2
drop _merge
* 2017's variables
merge m:1 folio yearEFH  using "$path/dta/Rouding_INR/variables_2017.dta"   ,replace update 
tab _merge year
drop if _merge==2
drop _merge
* Time elapsed
rename  yearEFH year_efh
merge m:1 folio year_efh  using "$path/dta/base_time_elapsed_wide.dta"
tab _merge year
drop if _merge==2
drop _merge
rename year_efh yearEFH
*------------------
* Rounding and use of brackets: 2011
merge m:1 folio yearEFH  using "$path/dta/Rouding_INR/ro_2011.dta" 
tab _merge year
drop if _merge==2
drop _merge
* Rounding and use of brackets: 2014
merge m:1 folio yearEFH  using "$path/dta/Rouding_INR/ro_2014.dta"  ,replace update  
tab _merge year
drop if _merge==2
drop _merge
* Rounding and use of brackets: 2017
merge m:1 folio yearEFH  using "$path/dta/Rouding_INR/ro_2017.dta"  ,replace update  
tab _merge year
drop if _merge==2
drop _merge


***************************************************************************************
* Variables explicativas
***************************************************************************************
* Household complexity variables
gen num_g2 =num_g 
recode num_g2 (4=3)
tab num_g2 ,nol

* Interviewer ID (by year and interv_id)
egen int_id=group(idenc yearEFH) if yearEFH!=2011
label var int_id "Interviewer's ID"
*tab int_id ,g(int_id_)
drop idenc

gen edad2=edad*edad
gen edad_d=int(edad/10)
label var edad_d "Age (in decades)"
g edadsq=edad_d*edad_d
label var edadsq "Age (in decades) squared"
gen terc_educ=(neduc>3)
label var terc_educ "Interviewed holds a post-secondary degree"
gen relationship =(est_civ==2)
label var relationship "In a relationship"
gen sobr_end=(perc_end==1|perc_end==2)
label var sobr_end "Household feels over-indebted"
gen       int_knowledge=(x_n3==3)
label var int_knowledge   "Good knowledge of the interviewed"
gen       int_disposition=(x_n5==3)
label var int_disposition "Good disposition of the interviewed"
g c6_act_indef2=c6_act_indef 
recode c6_act_indef2 2=1 7=1 4=3 6=3
lab def c6_act_indef2 1 "Self-employed" 3 "Civil servant" 5 "Private sector" 8 "Inactive or unemployed" 9 "Pensioner", modify
label values c6_act_indef2 c6_act_indef2
label var c6_act_indef2 "Occupational status"
gen n_cconhip=n_ccon+n_chip
label var n_cconhip "Number of loans"
gen p_estrato3   =(estrato==3)
label var p_estrato3 "If household belongs to highest 2 deciles"
/* Not working here
gen tipo_d=(tipo==9)
label var tipo_d "Type of banking debt"
lab def tipo_d 0 "Installment loan" 1 "Mortgage loan" , modify
label values tipo_d tipo_d
*/
gen education=1 if neduc==1 | neduc==2
replace education=2 if neduc==3
replace education=3 if neduc==4
replace education=4 if neduc==5
label var education "Education"
lab def education 1 "Only school" 2 "Technical education" 3 "University" 4 "Postgraduate" , modify
label values education education

gen male_nmarried=(genero==1 & married==0)
label var male_nmarried "Male, not married"
/*bys folio yearEFH: egen atr_12m_h=max(atr_12m)
label var atr_12m_h "Interviewed has had credit arrears in last 12 months"
*/

******************************************
* Time elapsed variable
******************************************
de max_elapsed_5 prom_elapsed_s_5 prom_elapsed_p_5 max_elapsed_9 prom_elapsed_s_9 prom_elapsed_p_9

foreach u in max_elapsed prom_elapsed_s prom_elapsed_p {
gen `u'=`u'_5 if tipo_deuda==3
replace `u'=`u'_9 if tipo_deuda==1
}

*****************************************
* Number of consumer and mortgage credits
*****************************************
gen     n_credits=n_ccon if tipo_deuda==3
replace n_credits=n_chip if tipo_deuda==1

*****************************************
* Rounding
*****************************************
gen     rounding_m=ro_m_td5 if tipo_deuda==3
replace rounding_m=ro_m_td9 if tipo_deuda==1
replace rounding_m=ro_m_td1 if tipo_deuda==4
replace rounding_m=ro_m_td2 if tipo_deuda==2
*---
gen     rounding_cf=ro_cf_td5 if tipo_deuda==3
replace rounding_cf=ro_cf_td9 if tipo_deuda==1
replace rounding_cf=ro_cf_td1 if tipo_deuda==4
replace rounding_cf=ro_cf_td2 if tipo_deuda==2
*---
gen     brackets_m=t_m_td5 if tipo_deuda==3
replace brackets_m=t_m_td9 if tipo_deuda==1
replace brackets_m=t_m_td1 if tipo_deuda==4
replace brackets_m=t_m_td2 if tipo_deuda==2
*---
gen     brackets_cf=t_cf_td5 if tipo_deuda==3
replace brackets_cf=t_cf_td9 if tipo_deuda==1
replace brackets_cf=t_cf_td1 if tipo_deuda==4
replace brackets_cf=t_cf_td2 if tipo_deuda==2
*---

*****************************************
* Ortogonal Rounding (only mortgages and consumer loans)
*****************************************
gen     orounding_m =ro_m_td9 if tipo_deuda==3
replace orounding_m =ro_m_td5 if tipo_deuda==1
*---
gen     orounding_cf=ro_cf_td9 if tipo_deuda==3
replace orounding_cf=ro_cf_td5 if tipo_deuda==1
*---
replace orounding_m=0 if orounding_m==.
replace orounding_cf=0 if orounding_cf==.


*****************************************
* Ortogonal Brackets (only mortgages and consumer loans)
*****************************************
gen     obrackets_m =t_m_td9 if tipo_deuda==3
replace obrackets_m =t_m_td5 if tipo_deuda==1
*---
gen     obrackets_cf=t_cf_td9 if tipo_deuda==3
replace obrackets_cf=t_cf_td5 if tipo_deuda==1
*---
replace obrackets_m=0 if obrackets_m==.
replace obrackets_cf=0 if obrackets_cf==.



***************************************************************************************
* Globals and additional variable definiions
***************************************************************************************
egen id=group(folio yearEFH)

/*global explic_var1 "male_nmarried married i.education edad_d edadsq"             
global explic_var2 "male_nmarried married i.education edad edad2"             
global explic_var3 " married i.education edad_d edadsq i.c6_act_indef2 i.genero"             
global explic_var4 " married i.education edad edad2 i.c6_act_indef2 i.genero i.estrato i.macrozona"             
global explic_var5 " married i.education edad edad2 i.c6_act_indef2 i.genero i.macrozona "             */
global explic_var6 " married i.education edad edad2 i.c6_act_indef2 i.genero i.refresco i.macrozona i.weekend i.yearEFH ib2.tipo_deuda "             

*------
/*global adicional   "numh i.n_encuestados n_ing n_cconhip d_transf i.macrozona refresco jefe_hog i.yearEFH"
global adicional2  "numh i.n_encuestados n_cconhip n_ingact gen_ing d_transf i.macrozona refresco i.yearEFH"
global adicional3  "numh n_cconhip n_ingact gen_ing d_transf i.macrozona "
global adicional4  "numh n_cconhip n_ing n_act gen_ing d_transf i.refresco i.yearEFH"
global adicional5 "numh n_cconhip n_ingact gen_ing d_transf i.refresco "
global adicional6 "numh n_cconhip n_ingact gen_ing d_transf i.refresco i.tipo_deudar"
global adicional7 "n_act gen_ing d_transf i.refresco ib2.tipo_deudar"
global adicional8 "n_act d_transf gen_ing i.refresco "
global adicional9 "i.refresco"
*global adicional9 "n_ingact i.refresco i.yearEFH" 
global adicional10 "d_nomax_ing i.refresco i.yearEFH"
global adicional11 "gen_ing i.refresco i.yearEFH "
global adicional12 "a1_nothighest_income i.refresco i.yearEFH "  */

* Proportional error definition
g E_error_ratio0 = 100*abs(error_ratio0) if error_ratio0>=-2 & error_ratio0<=2  //make them in %
g E_error_ratio0R = 100*abs(error_ratio0R) if error_ratio0R>=-2 & error_ratio0R<=2  //make them in %; rounding error

* Debt types
g tipo_deudar=tipo_deuda
replace tipo_deudar = 2 if (tipo_deuda == 2| tipo_deuda == 4)
lab def tipo_deudar 1 "Mortgages" 2 "Credit card and lines" 3 "Installment loans" , modify
label values tipo_deudar tipo_deudar

* TL to the logit
replace error_EFH_notSBIF=0 if ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==1) ///
& tipo_deuda==2) | ((deuda_linea_EFH==1 & deuda_linea_SBIF==1) & tipo_deuda==4)

replace error_EFH_notSBIF=1 if ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==0) ///
& tipo_deuda==2) | ((deuda_linea_EFH==1 & deuda_linea_SBIF==0) & tipo_deuda==4)

* Error not EFH and yes SBIF
g error_notEFH_SBIF=.
replace error_notEFH_SBIF=0 if ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==1) & tipo_deuda==4) | ///
((deuda_linea_EFH==1 & deuda_linea_SBIF==1) & tipo_deuda==2)  | ///
((deuda_hipotecario_EFH==1 & deuda_hipotecario_SBIF==1) & tipo_deuda==1) | ///
((deuda_prestamo_EFH==1 & deuda_prestamo_SBIF==1) & tipo_deuda==3)

replace error_notEFH_SBIF=1 if ((deuda_tarjeta_EFH==0 & deuda_tarjeta_SBIF==1) & tipo_deuda==4) | ///
((deuda_linea_EFH==0 & deuda_linea_SBIF==1) & tipo_deuda==2) | ///
((deuda_hipotecario_EFH==0 & deuda_hipotecario_SBIF==1) & tipo_deuda==1) | ///
((deuda_prestamo_EFH==0 & deuda_prestamo_SBIF==1) & tipo_deuda==3)
   
* Error  EFH and not SBIF
g error_EFH_notSBIF_v2=.
replace error_EFH_notSBIF_v2=0 if ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==1) & tipo_deuda==4) | ///
((deuda_linea_EFH==1 & deuda_linea_SBIF==1) & tipo_deuda==2)  | ///
((deuda_hipotecario_EFH==1 & deuda_hipotecario_SBIF==1) & tipo_deuda==1) | ///
((deuda_prestamo_EFH==1 & deuda_prestamo_SBIF==1) & tipo_deuda==3)

replace error_EFH_notSBIF_v2=1 if ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==0) & tipo_deuda==4) | ///
((deuda_linea_EFH==1 & deuda_linea_SBIF==0) & tipo_deuda==2) | ///
((deuda_hipotecario_EFH==1 & deuda_hipotecario_SBIF==0) & tipo_deuda==1) | ///
((deuda_prestamo_EFH==1 & deuda_prestamo_SBIF==0) & tipo_deuda==3) 
   
g tarj_lin=0
replace tarj_lin=1 if  (tipo_deuda==2 | tipo_deuda==4)

g tipo_deudat=1
replace tipo_deudat=2 if  (tipo_deuda==2 | tipo_deuda==4)
replace tipo_deudat=3 if  tipo_deuda==3

** Additional variables
* Split variable conoc_fondo: i) if interviewee responds the question about pension fund
* ii) interviewee knows the amount of his pension fund


g resp_fondo=(conoc_fondo<2)
lab def resp_fondo 0 "Does not apply" 1 "Int. responds about pension fund"
lab val resp_fondo resp_fondo

g sabe_fondo=(conoc_fondo==1)
lab def sabe_fondo 0 "Int. does not know" 1 "Int. knows"
lab val sabe_fondo sabe_fondo

g weekend=(dow==6 | dow==7)
lab def weekend 0 "Int. working days" 1 "Int. weekend"
lab val weekend weekend

g dispo_dum=0
replace dispo_dum=1 if x_n5==3
lab def dispo_dum 0 "Is not good" 1 "Int. dispo is good"
lab val dispo_dum dispo_dum

***************************************************************************************
* Variables explicativas - FROM FM's code
***************************************************************************************

* Variables explicativas
global base    "i.married i.education c.edad##c.edad i.c6_act_indef2 ib0.genero"
global survey  "i.refresco i.macrozona ib2014.yearEFH i.weekend miss_ingact round_ingact"
global others  "ib3.tipo_deudat i.dispo_dum"
global interviewer  "edad_enc ib0.genero_enc ib3.neduc_enc i.experiencia_enc"
global base2    "i.married i.education  i.c6_act_indef2 ib0.genero"
*i.num_g2 

g fondo_afp=0 if resp_fondo==0 & sabe_fondo==0
replace fondo_afp=1 if resp_fondo==1 & sabe_fondo==0
replace fondo_afp=2 if resp_fondo==1 & sabe_fondo==1
lab def fondo_afp 0 "Not apply" 1 "Don´t know" 2 "Know"
lab val fondo_afp fondo_afp

* Se crea variable de diferencia de edad entre entrevistado y encuestaador
g dif_age=edad-edad_enc
lab var dif_age "Difference in years between interviewee and interviewer"

global interviewer2  "dif_age ib0.genero_enc ib3.neduc_enc i.experiencia_enc"

* Regresiones agregadas por individuo
cd "$path/tablas\2021\int_margin"


* 1. Baseline
set more off
reg E_error_ratio0 $base $survey $others  if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , cluster(id)
outreg2 using "reg_int_fin.xls", replace dec(3) ctitle(Disp) keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income##i.tipo_deudat )

set more off
reg E_error_ratio0 $base $survey $others i.fondo_afp  if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , cluster(id)
outreg2 using "reg_int_fin.xls", append dec(3) ctitle(Disp+Fin) keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income##i.tipo_deudat )

set more off
reg E_error_ratio0 $base $survey $others i.fondo_afp i.num_g2  ///
if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , cluster(id)
outreg2 using "reg_int_fin.xls", append dec(3) ctitle(Disp+Fin+Nothigh) keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income##i.tipo_deudat )

set more off
reg E_error_ratio0 $base $survey $others i.fondo_afp i.a1_nothighest_income##i.tipo_deudat ///
if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , cluster(id)
outreg2 using "reg_int_fin.xls", append dec(3) ctitle(Disp+Fin+Nothigh) keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income##i.tipo_deudat )

set more off
reg E_error_ratio0 $base $survey $others i.fondo_afp i.num_g2 i.a1_nothighest_income##i.tipo_deudat ///
if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  , cluster(id)
outreg2 using "reg_int_fin.xls", append dec(3) ctitle(Disp+Fin+Nothigh) keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income##i.tipo_deudat )

set more off
reg E_error_ratio0 $base $survey $others i.fondo_afp  ///
if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2) & yearEFH>2011 , cluster(id)
outreg2 using "reg_int_fin.xls", append dec(3) ctitle(Disp+Fin+Nothigh no 11) keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income##i.tipo_deudat )

*set more off
*reg E_error_ratio0 $base $survey $others i.fondo_afp /*i.a1_nothighest_income##i.tipo_deudat*/ $interviewer  ///
*if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2) & yearEFH>2011 , cluster(id)
*outreg2 using "reg_int_fin.xls", append dec(3) ctitle(Disp+Fin+Nothigh+Enc no 11)

set more off
reg E_error_ratio0 $base $survey $others i.fondo_afp  i.int_id ///
if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2) & yearEFH>2011 , cluster(id)
outreg2 using "reg_int_fin.xls", append dec(3) ctitle(Disp+Fin+Nothigh+Enc no 11) keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income##i.tipo_deudat )

set more off
reg E_error_ratio0 $base $survey $others i.fondo_afp i.num_g2  i.int_id ///
if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2) & yearEFH>2011 , cluster(id)
outreg2 using "reg_int_fin.xls", append dec(3) ctitle(Disp+Fin+Nothigh+Enc no 11) keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income##i.tipo_deudat )

set more off
reg E_error_ratio0 $base $survey $others i.fondo_afp  i.a1_nothighest_income##i.tipo_deudat i.int_id ///
if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2) & yearEFH>2011 , cluster(id)
outreg2 using "reg_int_fin.xls", append dec(3) ctitle(Disp+Fin+Nothigh+Enc no 11) keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income##i.tipo_deudat )

set more off
reg E_error_ratio0 $base $survey $others i.fondo_afp i.num_g2 i.a1_nothighest_income##i.tipo_deudat i.int_id ///
if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2) & yearEFH>2011 , cluster(id)
outreg2 using "reg_int_fin.xls", append dec(3) ctitle(Disp+Fin+Nothigh+Enc no 11) keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income##i.tipo_deudat )

* Estimates by debt type

global others  "i.dispo_dum"

local deuda hip lyt prest

forv k=1/3 {

local m=word("`deuda'",`k')

* 1. Baseline
set more off
reg E_error_ratio0 $base $survey $others  if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2) & tipo_deudat==`k' , cluster(id)
outreg2 using "reg_int_fin_`m'.xls", replace dec(3) ctitle(Disp) ///
keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income )

reg E_error_ratio0 $base $survey $others i.fondo_afp  if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  & tipo_deudat==`k' , cluster(id)
outreg2 using "reg_int_fin_`m'.xls", append dec(3) ctitle(Disp+Fin) ///
keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income )

reg E_error_ratio0 $base $survey $others i.fondo_afp i.num_g2  ///
if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  & tipo_deudat==`k' , cluster(id)
outreg2 using "reg_int_fin_`m'.xls", append dec(3) ctitle(Disp+Fin+Nothigh) ///
keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income )

reg E_error_ratio0 $base $survey $others i.fondo_afp i.a1_nothighest_income ///
if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  & tipo_deudat==`k' , cluster(id)
outreg2 using "reg_int_fin_`m'.xls", append dec(3) ctitle(Disp+Fin+Nothigh) ///
keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income )

reg E_error_ratio0 $base $survey $others i.fondo_afp i.num_g2 i.a1_nothighest_income ///
if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  & tipo_deudat==`k' , cluster(id)
outreg2 using "reg_int_fin_`m'.xls", append dec(3) ctitle(Disp+Fin+Nothigh) ///
keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income )

reg E_error_ratio0 $base $survey $others i.fondo_afp  ///
if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2) & yearEFH>2011  & tipo_deudat==`k', cluster(id)
outreg2 using "reg_int_fin_`m'.xls", append dec(3) ctitle(Disp+Fin+Nothigh no 11) ///
keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income )

reg E_error_ratio0 $base $survey $others i.fondo_afp  i.int_id ///
if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2) & yearEFH>2011  & tipo_deudat==`k', cluster(id)
outreg2 using "reg_int_fin_`m'.xls", append dec(3) ctitle(Disp+Fin+Nothigh+Enc no 11) ///
keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income )

reg E_error_ratio0 $base $survey $others i.fondo_afp i.num_g2  i.int_id ///
if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2) & yearEFH>2011  & tipo_deudat==`k', cluster(id)
outreg2 using "reg_int_fin_`m'.xls", append dec(3) ctitle(Disp+Fin+Nothigh+Enc no 11) ///
keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income##i.tipo_deudat )

reg E_error_ratio0 $base $survey $others i.fondo_afp  i.a1_nothighest_income i.int_id ///
if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2) & yearEFH>2011  & tipo_deudat==`k', cluster(id)
outreg2 using "reg_int_fin_`m'.xls", append dec(3) ctitle(Disp+Fin+Nothigh+Enc no 11) ///
keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income )

reg E_error_ratio0 $base $survey $others i.fondo_afp i.num_g2 i.a1_nothighest_income i.int_id ///
if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2) & yearEFH>2011  & tipo_deudat==`k', cluster(id)
outreg2 using "reg_int_fin_`m'.xls", append dec(3) ctitle(Disp+Fin+Nothigh+Enc no 11) ///
keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income )

}

* Credit card + credit line +  prest

* 1. Baseline
set more off
reg E_error_ratio0 $base $survey $others  if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2) & (tipo_deudat==2 | tipo_deuda==3) , cluster(id)
outreg2 using "reg_int_fin_cons.xls", replace dec(3) ctitle(Disp) ///
keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income )

reg E_error_ratio0 $base $survey $others i.fondo_afp  if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2) ///
& (tipo_deudat==2 | tipo_deuda==3) , cluster(id)
outreg2 using "reg_int_fin_cons.xls", append dec(3) ctitle(Disp+Fin) ///
keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income )

reg E_error_ratio0 $base $survey $others i.fondo_afp i.num_g2  ///
if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2) & (tipo_deudat==2 | tipo_deuda==3) , cluster(id)
outreg2 using "reg_int_fin_cons.xls", append dec(3) ctitle(Disp+Fin+Nothigh) ///
keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income )

reg E_error_ratio0 $base $survey $others i.fondo_afp i.a1_nothighest_income ///
if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2) & (tipo_deudat==2 | tipo_deuda==3) , cluster(id)
outreg2 using "reg_int_fin_cons.xls", append dec(3) ctitle(Disp+Fin+Nothigh) ///
keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income )

reg E_error_ratio0 $base $survey $others i.fondo_afp i.num_g2 i.a1_nothighest_income ///
if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2)  & (tipo_deudat==2 | tipo_deuda==3) , cluster(id)
outreg2 using "reg_int_fin_cons.xls", append dec(3) ctitle(Disp+Fin+Nothigh) ///
keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income )

reg E_error_ratio0 $base $survey $others i.fondo_afp  ///
if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2) & yearEFH>2011  & (tipo_deudat==2 | tipo_deuda==3), cluster(id)
outreg2 using "reg_int_fin_cons.xls", append dec(3) ctitle(Disp+Fin+Nothigh no 11) ///
keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income )

reg E_error_ratio0 $base $survey $others i.fondo_afp  i.int_id ///
if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2) & yearEFH>2011 & (tipo_deudat==2 | tipo_deuda==3), cluster(id)
outreg2 using "reg_int_fin_cons.xls", append dec(3) ctitle(Disp+Fin+Nothigh+Enc no 11) ///
keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income )

reg E_error_ratio0 $base $survey $others i.fondo_afp i.num_g2  i.int_id ///
if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2) & yearEFH>2011  & (tipo_deudat==2 | tipo_deuda==3), cluster(id)
outreg2 using "reg_int_fin_cons.xls", append dec(3) ctitle(Disp+Fin+Nothigh+Enc no 11) ///
keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income##i.tipo_deudat )

reg E_error_ratio0 $base $survey $others i.fondo_afp  i.a1_nothighest_income i.int_id ///
if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2) & yearEFH>2011 & (tipo_deudat==2 | tipo_deuda==3), cluster(id)
outreg2 using "reg_int_fin_cons.xls", append dec(3) ctitle(Disp+Fin+Nothigh+Enc no 11) ///
keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income )

reg E_error_ratio0 $base $survey $others i.fondo_afp i.num_g2 i.a1_nothighest_income i.int_id ///
if reporut_2017!=0 & (error_ratio0>-2 & error_ratio0<2) & yearEFH>2011 & (tipo_deudat==2 | tipo_deuda==3), cluster(id)
outreg2 using "reg_int_fin_cons.xls", append dec(3) ctitle(Disp+Fin+Nothigh+Enc no 11) ///
keep($base $others i.fondo_afp i.num_g2 i.a1_nothighest_income )
