********************************************************
* Rounding variables and INR, EFH 2017
********************************************************

set more off
clear
global path "C:\Users\pedro\Dropbox"
use "$path\Cruce\Paper descriptivo\Stata\efh_dta\EFH_17_allvars.dta", clear
keep if ord==1

***************************
* Naming mortgage variables
***************************
drop m_td9* m_td10* m_td11* m_td12* m_td13* cf_td9* cf_td10* cf_td12* cf_td13*
gen m_td9_1  =m_vp_fch if t_chvp==1
gen m_td5_4  =m_vp_foc if t_ocvp==1
replace m_td9_1  =0 if t_chvp==0
replace m_td5_4  =0 if t_ocvp==0
***
gen cf_td9_1 =div_chvp  if t_chvp==1
gen cf_td5_4 =div_ocvp  if t_ocvp==1
replace cf_td9_1 =0  if t_chvp==0
replace cf_td5_4 =0  if t_ocvp==0
*******
forv r=1/3 {
local j=`r'+1
local h=`r'+4
gen m_td9_`j'=m_otp_fch_`r' if t_chotp_`r'==1
gen m_td5_`h'=m_otp_foc_`r' if t_ocotp_`r'==1
replace m_td9_`j'=0 if t_chotp_`r'==0
replace m_td5_`h'=0 if t_ocotp_`r'==0
***
gen cf_td9_`j'=div_chotp_`r' if t_chotp_`r'==1
gen cf_td5_`h'=div_ocotp_`r' if t_ocotp_`r'==1
replace cf_td9_`j'=0 if t_chotp_`r'==0
replace cf_td5_`h'=0 if t_ocotp_`r'==0

}
de cf_td9_* m_td9_* cf_td5_* m_td5_*


********************************************
* Member of the household who holds the debt
********************************************
drop f3_t9* f3_t10* f3_t11* f3_t12* f3_t13*
forv k=1/8 {
forv m=1/4 {
capture: rename f3_t`k'd`m' f3_td`k'_`m'
}
}
* Mortgage debt (only EFH 2017)
gen e14=min(e14_1, e14_2, e14_3)
forv i=1/3 {
gen e56_`i'=min(e56_1_`i', e56_2_`i', e56_3_`i')
}
drop e14_* e56_*_*
*****
rename (e14 e56_1 e56_2 e56_3) (e14_1 e14_2 e14_3 e14_4)
forv k=1/4 {
g f3_td9_`k'=e14_`k' if cf_td9_`k'>0
}
g f3_td5_4=1 if cf_td5_4>0
forv k=1/3 {
local p=`k'+4
g f3_td5_`p'=1 if cf_td5_`p'>0
}



******************************************
* Debt variables construction for rounding
******************************************
* Consumption amounts
forv m=1(1)4 {
	forv k=1(2)3 {
	capture: gen mo_td`k'_`m'=f7_t`k'd`m' if f7_t`k'd`m'>0               & f3_td`k'_`m'==1                         // original amount
	capture: gen t_mo_td`k'_`m'=(f7t_t`k'd`m'>0 & f7t_t`k'd`m'<98        & f3_td`k'_`m'==1) if m_td`k'_`m'!=0      // original amount answer in brackets
	*******
	capture: gen ds_td`k'_`m'=f10_t`k'd`m' if f10_t`k'd`m'>0             & f3_td`k'_`m'==1                         // debt service
	capture: gen t_ds_td`k'_`m'=(f10t_t`k'd`m'>0 & f10t_t`k'd`m'<98      & f3_td`k'_`m'==1) if cf_td`k'_`m'!=0      // debt service answer in brackets
	}
	forv k=2/2 {
	capture: gen mo_td`k'_`m'=f13_t`k'd`m' if f13_t`k'd`m'>0             & f3_td`k'_`m'==1       // original amount
	capture: gen t_mo_td`k'_`m'=(f13t_t`k'd`m'>0 & f13t_t`k'd`m'<98      & f3_td`k'_`m'==1) if m_td`k'_`m'!=0      // original amount answer in brackets
	*******
	capture: gen ds_td`k'_`m'=f13_t`k'd`m' if f13_t`k'd`m'>0             & f3_td`k'_`m'==1       // debt service
	capture: gen t_ds_td`k'_`m'=(f13t_t`k'd`m'>0 & f13t_t`k'd`m'<98      & f3_td`k'_`m'==1) if cf_td`k'_`m'!=0      // debt service answer in brackets
	}
	forv k=4/7 {
	capture: gen mo_td`k'_`m'=f16_t`k'd`m' if f16_t`k'd`m'>0             & f3_td`k'_`m'==1       // original amount
	capture: gen t_mo_td`k'_`m'=(f16t_t`k'd`m'>0 & f16t_t`k'd`m'<98      & f3_td`k'_`m'==1) if m_td`k'_`m'!=0       // original amount answer in brackets
	*******
	capture: gen ds_td`k'_`m'=f23_t`k'd`m' if f23_t`k'd`m'>0             & f3_td`k'_`m'==1       // debt service
	capture: gen t_ds_td`k'_`m'=(f23t_t`k'd`m'>0 & f23t_t`k'd`m'<98      & f3_td`k'_`m'==1) if cf_td`k'_`m'!=0      // debt service answer in brackets
	}
	forv k=8/8 {
	capture: gen mo_td`k'_`m'=f30_t`k'd`m' if f30_t`k'd`m'>0             & f3_td`k'_`m'==1       // original amount
	capture: gen t_mo_td`k'_`m'=(f30t_t`k'd`m'>0 & f30t_t`k'd`m'<98      & f3_td`k'_`m'==1) if m_td`k'_`m'!=0      // original amount answer in brackets
	*******
	capture: gen ds_td`k'_`m'=f35_t`k'd`m' if f35_t`k'd`m'>0             & f3_td`k'_`m'==1       // debt service *************************
	capture: gen t_ds_td`k'_`m'=(f35t_t`k'd`m'>0 & f35t_t`k'd`m'<98      & f3_td`k'_`m'==1) if cf_td`k'_`m'!=0      // debt service answer in brackets
	}
}
de mo_* ds_* t_mo_* t_ds_*

* Mortgage amounts
foreach u in e15_pesos e15_uf e15_esc e20_pesos e20_uf e57_pesos_1 e57_uf_1 e57_pesos_2 e57_uf_2 e57_pesos_3 e57_uf_3 e61_pesos_1 e61_uf_1 e61_pesos_2 e61_uf_2 e61_pesos_3 e61_uf_3 e32_pesos e32_uf  e73_pesos_1 e73_uf_1 e73_pesos_2 e73_uf_2 e73_pesos_3 e73_uf_3 {
replace `u'=. if `u'<=0
}
* Initial amount CH VP
egen    mo_td9_1=rsum(e15_pesos e15_uf e15_esc) ,miss
egen    eeee=rsum(e20_pesos e20_uf) ,miss
replace mo_td9_1=eeee if e16==1
replace mo_td9_1=. if t_chvp==0             | f3_td9_1!=1
drop    eeee
*****
gen     t_mo_td9_1=(e15t>0 & e15t<98        & f3_td9_1==1)
replace t_mo_td9_1=(e20t>0 & e20t<98        & f3_td9_1==1) if e16==1
replace t_mo_td9_1=. if t_chvp==0      | f3_td9_1!=1

* Initial amount CH OTP
forv i=1/3 {
local j=`i'+1
egen    mo_td9_`j'=rsum(e57_pesos_`i' e57_uf_`i') ,miss
egen    eeee=rsum(e61_pesos_`i' e61_uf_`i') ,miss
replace mo_td9_`j'=eeee if e58_`i'==1
replace mo_td9_`j'=. if t_chotp_`i'==0              | f3_td9_`j'!=1
drop    eeee
*****
gen     t_mo_td9_`j'=(e57t_`i'>0 & e57t_`i'<98      & f3_td9_`j'==1)
replace t_mo_td9_`j'=(e61t_`i'>0 & e61t_`i'<98      & f3_td9_`j'==1) if e58_`i'==1
replace t_mo_td9_`j'=. if t_chotp_`i'==0    | f3_td9_`j'!=1
}
* Initial amount CC VP
egen    mo_td5_4=rsum(e32_pesos e32_uf) ,miss
replace mo_td5_4=. if t_ocvp==0
****
gen   t_mo_td5_4=(e32t>0 & e32t<98)
replace t_mo_td5_4=. if t_ocvp==0
* Initial amount CC OTP
forv i=1/3 {
local j=`i'+4
egen    mo_td5_`j'=rsum(e73_uf_`i' e73t_`i') ,miss
replace mo_td5_`j'=. if t_ocotp_`i'==0
****
gen     t_mo_td5_`j'=(e73t_`i'>0 & e73t_`i'<98)
replace t_mo_td5_`j'=. if t_ocotp_`i'==0
}
*********
* Debt service
* CH VP and OTP
gen   ds_td9_1  =e28 if e28>0 &  t_chvp==1          & f3_td9_1==1        
gen   t_ds_td9_1=(e28t>0 & e28t<98 & f3_td9_1==1    & f3_td9_1==1)     // answer in brackets
replace t_ds_td9_1=. if t_chvp==0    | f3_td9_1!=1
forv i=1/3 {
local j=`i'+1
gen   ds_td9_`j'  =e69_`i' if e69_`i'>0 &  t_chotp_`i'==1                & f3_td9_`j'==1        
gen   t_ds_td9_`j'=(e69t_`i'>0 & e69t_`i'<98                             & f3_td9_`j'==1)     // answer in brackets
replace   t_ds_td9_`j'=. if t_chotp_`i'==0
}
* CC VP and OTP
gen   ds_td5_4  =e37 if e37>0 &  t_ocvp==1         
gen   t_ds_td5_4=(e37t>0 & e37t<98)     // answer in brackets
replace t_ds_td5_4=. if t_ocvp==0
forv i=1/3 {
local j=`i'+4
gen   ds_td5_`j'  =e78_`i' if e78_`i'>0 &  t_ocotp_`i'==1         
gen   t_ds_td5_`j'=(e78t_`i'>0 & e78t_`i'<98)     // answer in brackets
replace   t_ds_td5_`j'=. if t_ocotp_`i'==0
}
de mo_td5* ds_td5* t_mo_td5* t_ds_td5*    mo_td9* ds_td9* t_mo_td9* t_ds_td9*

* Global variables for debt
foreach u in mo_td ds_td t_mo_td t_ds_td m_td cf_td {
global `u'1 "`u'1_1 `u'1_2 `u'1_3"
global `u'2 "`u'2_1 `u'2_2 `u'2_3"
global `u'3 "`u'3_1 `u'3_2 `u'3_3 `u'3_4"
global `u'4 "`u'4_1 `u'4_2 `u'4_3"
global `u'5 "`u'5_1 `u'5_2 `u'5_3 `u'5_4 `u'5_5 `u'5_6 `u'5_7"
global `u'6 "`u'6_1 `u'6_2 `u'6_3"
global `u'7 "`u'7_1 `u'7_2 `u'7_3"
global `u'8 "`u'8_1 `u'8_2 `u'8_3"
global `u'9 "`u'9_1 `u'9_2 `u'9_3 `u'9_4"
****
global `u' "$`u'1 $`u'2 $`u'3 $`u'4 $`u'5 $`u'6 $`u'7 $`u'8 $`u'9"
}

* Assets and incomes variables
rename act_vp vivp
******
global yoprinmh          "yoprinm"  
global yoprinh           "yoprin_otro_1 yoprin_otro_2 yoprin_otro_3 yoprin_otro_4"  
global yosech            "yosec"  
global ypenh             "y_pen_1 y_pen_2 y_pen_3 y_pen_4 y_pen_5 y_pen_6 y_pen_7"  
global ysubh             "y_sub_9 y_sub_10 y_sub_11 y_sub_12 y_sub_13 y_sub_14 y_sub_15"
global yotroh            "y_otro_1 y_otro_2 y_otro_3 y_otro_4 y_otro_5 y_otro_6 y_otro_7 y_otro_9 y_otro_14 y_otro_15 y_otro_16 y_otro_17"
*---
global act_vp            "vivp"
global act_otp           "e50_1 e50_2 e50_3"
global act_vehicyotros   "act_aut act_mot act_utt act_otros act_otrosvehic"
global act_var           "act_acc act_fm act_rv act_ps"
global act_fijo          "act_rf act_ca act_apv"

* Rename to brackets
rename (j1t    j2t_1           j2t_2           j2t_3           j2t_4            j3t      l2t_1     l2t_2     l2t_3     l2t_4     l2t_5     l2t_6     l2t_7      l2t_9     l2t_10     l2t_11     l2t_12     l2t_13     l2t_14     l2t_15      l5t_1      l5t_2      l5t_3      l5t_4      l5t_5      l5t_6      l5t_7      l5t_9      l5t_14      l5t_15      l5t_16      l5t_17) /*
*/ (yoprinm_t  yoprin_otro_1_t yoprin_otro_2_t yoprin_otro_3_t yoprin_otro_4_t  yosec_t  y_pen_1_t y_pen_2_t y_pen_3_t y_pen_4_t y_pen_5_t y_pen_6_t y_pen_7_t  y_sub_9_t y_sub_10_t y_sub_11_t y_sub_12_t y_sub_13_t y_sub_14_t y_sub_15_t  y_otro_1_t y_otro_2_t y_otro_3_t y_otro_4_t y_otro_5_t y_otro_6_t y_otro_7_t y_otro_9_t y_otro_14_t y_otro_15_t y_otro_16_t y_otro_17_t)
rename (e8t   e50t_1  e50t_2  e50t_3    h3t_1     h3t_2     h3t_3     h5t         h3t_4              i2t_1     i2t_2    i2t_6    i2t_7      i2t_3    i2t_4    i2t_5) /*
*/ (vivp_t   e50_1_t e50_2_t e50_3_t   act_aut_t act_mot_t act_utt_t act_otros_t act_otrosvehic_t   act_acc_t act_fm_t act_rv_t act_ps_t   act_rf_t act_ca_t act_apv_t)

* $yoprinh annually
foreach u in $yoprinh   {
replace `u'=`u'*12
}


******************************************
* Rounding (Gideon, Hsu and McFall (2015))
******************************************
foreach u in $mo_td $ds_td      $yoprinmh $yoprinh $yosech $ypenh $ysubh $yotroh  $act_vp $act_otp $act_vehicyotros $act_var $act_fijo {
replace `u'=int(`u')
*replace `u'=int(`u'/1000)
tostring `u' ,replace force
gen large=length(`u')
gen trailing=large-length(reverse(substr(reverse(`u'), indexnot(reverse(`u'), "0"),.)))
destring `u' ,replace
gen ro_`u'=(trailing)/(large-1)            // rounding meassure
drop large trailing
}
foreach u in  $yoprinmh $yoprinh $yosech $ypenh $ysubh $yotroh  $act_vp $act_otp $act_vehicyotros $act_var $act_fijo {
replace ro_`u'=. if `u'_t<98 
}
rename (ro_mo_td* ro_ds_td* t_mo_td* t_ds_td*) (ro_m_td* ro_cf_td* t_m_td* t_cf_td*) // convenient renaming

* Agregating rounding variables
foreach h in yoprinmh yoprinh yosech ypenh ysubh yotroh  act_vp act_otp act_vehicyotros act_var act_fijo {
global ro_`h' ""
foreach e in $`h' {
global ro_`h' ${ro_`h'} ro_`e'
}
egen ro_`h'  =rmean(${ro_`h'})
}
forv i=1/9 {
egen ro_m_td`i'  =rmax(ro_m_td`i'_*)
egen ro_cf_td`i'=rmax(ro_cf_td`i'_*)
egen t_cf_td`i'=rmax(t_cf_td`i'_*)
egen t_m_td`i'=rmax(t_m_td`i'_*)
} 

egen ro_cf_td_no5_9 =rmean(ro_cf_td1_* ro_cf_td2_* ro_cf_td3_* ro_cf_td4_* ro_cf_td6_* ro_cf_td7_* ro_cf_td8_*)
egen ro_m_td_no5_9  =rmean(ro_m_td1_* ro_m_td2_* ro_m_td3_* ro_m_td4_* ro_m_td6_* ro_m_td7_* ro_m_td8_*)
*egen t_cf_td_no5_9 =rmax(t_cf_td1_* t_cf_td2_* t_cf_td3_* t_cf_td4_* t_cf_td6_* t_cf_td7_* t_cf_td8_*)
*egen t_m_td_no5_9  =rmax(t_m_td1_* t_m_td2_* t_m_td3_* t_m_td4_* t_m_td6_* t_m_td7_* t_m_td8_*)


* 	Stats
tabstat ro_m_td* ro_cf_td* ro_yoprinmh ro_yoprinh ro_yosech ro_ypenh ro_ysubh ro_yotroh ro_act_vp ro_act_otp ro_act_vehicyotros ro_act_var ro_act_fijo  ,s(p10 p50 mean n)  columns(statistics)


/*
* Rounding in agregate variables
foreach y in ro {
egen `y'_ing   =rmean(`y'_yoprinmh `y'_yoprinh `y'_yosech `y'_ypenh `y'_ysubh `y'_yotroh)
}
*/

********
* INR
********
* INR dummies
forv i=1/9 {
	forv j=1/7 {
	capture: gen inr_m_td`i'_`j'=(m_td`i'_`j'==.)   if m_td`i'_`j'!=0  & f3_td`i'_`j'==1 
	capture: gen inr_cf_td`i'_`j'=(cf_td`i'_`j'==.) if cf_td`i'_`j'!=0 & f3_td`i'_`j'==1 
	}
}

* Stats
tabstat inr_m_td* ,s(mean n)  columns(statistics)
tabstat inr_cf_td* ,s(mean n)  columns(statistics)
forv i=1/9 {
	forv j=1/3 {
	tab ro_m_td`i'_`j' t_m_td`i'_`j' ,miss
	}
}
tab ro_m_td5_4 t_m_td5_4 ,miss
tab ro_m_td5_5 t_m_td5_5 ,miss
tab ro_m_td5_6 t_m_td5_6 ,miss
tab ro_m_td5_7 t_m_td5_7 ,miss



********
* Saving
********
gen yearEFH=2017
order folio yearEFH
keep folio yearEFH cf_td9* cf_td5* m_td5* m_td9* ro_m_td* ro_cf_td* t_m_td* t_cf_td* ro_yoprinmh ro_yoprinh ro_yosech ro_ypenh ro_ysubh ro_yotroh ro_act_vp ro_act_otp ro_act_vehicyotros ro_act_var ro_act_fijo
save "$path\Cruce\Paper descriptivo\Stata\dta\Rouding_INR\ro_2017.dta" ,replace
