********************************************************
* Rounding variables and INR, EFH 2014
********************************************************

set more off
clear
global path "C:\Users\pedro\Dropbox"
use "$path\Cruce\Paper descriptivo\Stata\efh_dta\EFH_14_allvars.dta", clear

***************************************************************************************
*-----------------------------------------------------------------------
* Tramos se pasan a "."
*-----------------------------------------------------------------------
* Deuda residual y dividendo hipotecaria vp
replace d_chvp=. if e35t<98 
replace div_chvp=. if e35t<98 
* Deuda residual y dividendo cc vp
replace d_ccvp=. if e44t<98 
replace div_ccvp=. if e44t<98 
* Deuda residual hipotecaria y cc y dividendo otp
forv i=1/3 {
replace d_chotp_`i'=.   if e72t_`i'<98
replace div_chotp_`i'=. if e72t_`i'<98
**
replace d_ccotp_`i'=.   if e81t_`i'<98
replace div_ccotp_`i'=. if e81t_`i'<98
}
* Deuda inicial hipo vp
replace e19=. if e19t<98 
* Deuda inicial cc vp
replace e39=. if e39t<98 
* Deuda inicial hipotecaria OTP
forv i=1/3 {
*hipo
replace e56_`i'=. if e56t_`i'<98 
*cc
replace e76_`i'=. if e76t_`i'<98 
}
* Consumo
forv m=1/3 {                                            
replace cf_td2_`m'=. if  f12t_t2d`m'<98
replace d_td2_`m'=. if  f12t_t2d`m'<98
}
forv k=1(2)3 {                                               
forv m=1/3 {                                                  
replace cf_td`k'_`m'=. if  f9t_t`k'd`m'<98 
replace d_td`k'_`m'=. if  f9t_t`k'd`m'<98                 
}
}
replace cf_td3_4=. if  f9t_t3d4<98 
replace d_td3_4=. if  f9t_t3d4<98                 
forv k=4/7 {                                               
forv m=1/3 {                                                 
replace  cf_td`k'_`m'=. if   f24t_t`k'd`m'<98
replace  d_td`k'_`m'=. if   f24t_t`k'd`m'<98
}
}
forv m=1/3 {
replace cf_td8_`m'=. if f38t_t8d`m'<98 | f41t_t8d`m'<98
replace d_td8_`m'=. if f38t_t8d`m'<98  | f41t_t8d`m'<98
}
**************************************************************************************


******************************************************************************************************************************************************
* Variables de interés EFH 2014
******************************************************************************************************************************************************
* Hora y tiempo entrevista
merge m:1 folio using "$path\Cruce\Paper descriptivo\Stata\efh_dta\Tiempos_EFH2014.dta"
drop if _merge==2
drop _merge
tab year_e anoe
tab mese month_e
*---
gen     time_e=1 if hora_e>=6   & hora_e<12
replace time_e=2 if hora_e>=12  & hora_e<17
replace time_e=3 if hora_e>=17  & hora_e<21
replace time_e=4 if (hora_e>=21 & hora_e<=23) | (hora_e>=0  & hora_e<6)
tab hora_e time_e

* Número de preguntas que responde el encuestado
order n1 f*_orden_* *_orden ,last
gen n_preg_e=0 if ord==1 
local i=0
foreach u of varlist a2-l5t_16 {
capture: replace n_preg_e=n_preg_e+1 if `u'!=. & ord==1
capture: replace n_preg_e=n_preg_e+1 if `u'!="" & ord==1
local i=`i'+1
}
di `i'

* Número de segundos por pregunta
gen n_seg_e=(duracion_e*60/n_preg)

* Union modulos mno EFH 2014
rename folio folio_2014
joinby folio_2014 using "$path\Cruce\Paper descriptivo\Stata\efh_dta\bcch_efh2014_hogares_modulos_mno_.dta", unm(b)
tab _merge
drop if _merge==2
drop _merge

* Número de créditos por hogar
egen n_ccon=rsum(f2_t*)
egen n_chip=rsum(t_chvp t_ccvp t_chotp_* t_ccotp_* )
label var n_ccon "Number of credit loans"
label var n_chip "Number of mortgage loans"

* Days of the week
gen dow = dow(mdy(mese,diae,2014))
replace dow=dow+1  // 1 lunes, 2 martes...
tab dow if ord==1

* Disposición a participar EFH 2017
g disp_efh2017=(m8==1)
tab disp_efh2017 ,miss

* Uso docs
gen uso_docs=(n2==1)
tab uso_docs ,miss

* Número de encuestados
bys folio_2014: egen n_encuestados=sum(n1)
replace n_encuestados=3 if n_encuestados>2
tab n_encuestados ,miss

* Concimiento y disposición de los entrevidados
foreach u in n3 n5 {
gen x_`u'=0
replace x_`u'=1 if `u'<4
replace x_`u'=2 if `u'>=4 & `u'<=7 
replace x_`u'=3 if `u'>7
lab val x_`u' x_`u'_1
}
tab x_n3  ,miss
tab x_n5  ,miss

* Panel variable
recode tm 4=3
gen refresco= tm
recode refresco 2=1 
recode refresco (1=0) (3=1)
tab refresco tm ,miss

*Head of household
gen jefe_hog=(a2==1 & edad>=18)
tab jefe_hog ,miss

* Número de adultos
g aux_ed=(edad>=18)
bysort folio_2014: egen num_adul=sum(aux_ed)
tab num_adul, miss

* Numero de personas con ingresos primarios
g aux_ing=(j1!=. | j3!=.)
bysort folio_2014: egen gen_ing=sum(aux_ing)
tab gen_ing ,miss

* Estabilidad empleo
tab c13 ,miss
gen est_emp=c13 
recode est_emp (9=8)
replace est_emp=6 if est_emp==.
tab est_emp if ord==1,miss

* Percepción endeudamiento
tab g1 ,miss
gen perc_end=g1
recode perc_end (.=10) (8=9)
tab perc_end if ord==1 ,miss

* lugar de entrevista
g lug_entrev=o4
recode lug_entrev 2/3=2 4/6=3

* Prob de responder de nuevo
g prob_resp=o8

* Dificultad en aceptación
g dif_acep=o6

* Si se cambiará de domicilio
g camb_dom=(m6==1)

* Si el individuo no tiene la edad máxima del hogar
bys folio_2014: egen max_edad=max(edad)
gen d_nomax_edad=(edad<max_edad)


*****************************************************************************************************************************************************
* Labels values
*****************************************************************************************************************************************************
label def disp_efh2017 1 "Willingness to participate in future SHFs" 0 "Unwilligness to participate in future SHFs"
label val disp_efh2017 disp_efh2017
label def uso_docs 1 "Use of documents" 0 "Do not use documents"
label val uso_docs uso_docs
lab def n_encuestados_l 1 "One adult" 2 "Two adult" 3 "More than two adults" 
lab val n_encuestados n_encuestados_l
foreach u in n3 n5 {
lab def x_`u'_1 1 "Bad" 2 "Normal" 3 "Good"
lab val x_`u' x_`u'_1
}
lab def refresco_l 0 "Panel sample" 1 "First time interviewed" 
lab val refresco refresco_l
lab def est_emp 1 "Very stable" 2 "Stable" 3 "Neither stable nor unstable" 4 "Unstable" 5 "Very unstable" 6 "Does not apply" 8 "No answer" , modify
label values est_emp est_emp
lab def perc_end 1 "Excessive" 2 "High" 3 "Moderate" 4 "Low" 9 "No answer" 10 "Does not apply", modify
label values perc_end perc_end
label def lug_entrev 1 "Inside home" 2 "Garden or home reception" 3 "Outside home" 
label val lug_entrev lug_entrev
label def prob_resp 1 "Very unlikely" 2 "Unlikely" 3 "Likely" 4 "Very likely" 5 "Hard to assess"
label val prob_resp prob_resp
label def dif_acep 1 "Very easy" 2 "Easy" 3 "Normal" 4 "Hard" 5 "Very hard"
label val dif_acep dif_acep
label def camb_dom 1 "Expect" 0 "Does not expect"
label val camb_dom camb_dom
label def dow 1 "Monday"  2 "Tuesday" 3 "Wednesday"  4 "Thursday" 5 "Friday" 6 "Saturday" 7 "Sunday"  
label val dow dow 
label def time_e 1 "Morning"  2 "Afternoon" 3 "Evening"  4 "Night"  
label val time_e time_e 

*****************************************************************************************************************************************************
* Labels variables
*****************************************************************************************************************************************************
label var n_ccon	"Number of consumer loans of the household"
label var n_chip	"Number of mortgage loans of the household"
label var gen_ing	"Number of household members with labor income"
label var refresco	"If the household was interviewed for the first time" 
label var jefe_hog	"If the interviewed is the head of household"
label var dow	"Day of the interview"
label var conoc_fondo	"If interviewed knows his/her pension fund category "
label var x_n3	"Interviewed knowledge according to the interviewer's perception"
label var x_n5	"Interviewed disposition according to the interviewer's perception"
label var est_emp	"Employment stability according to the interviewed"
label var cotiz	"If the interviewed is currently quoting in an AFP"
label var disp_efh2017	"The willingness of the household to participate in the next SHF" 
label var duracion_e	"Total length of the interview"
label var time_e	"Time of the day when the interview was answered"
label var n_preg_e	"Total number of answered questions"
label var n_seg_e	   "Average time spent per question (in seconds)"
label var uso_docs	"If the interviewed uses records"
label var n_encuestados	"Adults present during the interview"
label var perc_end	"Indebtedness perception of the household"
label var lug_entrev	"Interviewing context"
label var prob_resp	"Probability to answer in next waves according to the interviewer"
label var dif_acep	"Answer acceptance"
label var d_nomax_edad "Interviewed is not the highest age of the household"
label var num_adul	"Number of adults in the household"
label var camb_dom	"Address change expectation of the household"


********
* Saving
********
keep if ord==1
rename folio_2014 folio
gen yearEFH=2014
order folio yearEFH 
keep folio yearEFH time_e n_preg_e n_seg_e n_ccon n_chip disp_efh2017 uso_docs dow n_encuestados x_n3 x_n5 refresco jefe_hog num_adul gen_ing est_emp perc_end lug_entrev dif_acep camb_dom d_nomax_edad

sum time_e n_preg_e n_seg_e n_ccon n_chip disp_efh2017 uso_docs dow n_encuestados x_n3 x_n5 refresco jefe_hog num_adul gen_ing est_emp perc_end lug_entrev dif_acep camb_dom d_nomax_edad 
foreach u of varlist time_e n_preg_e n_ccon n_chip disp_efh2017 uso_docs dow n_encuestados x_n3 x_n5 refresco jefe_hog num_adul gen_ing est_emp perc_end lug_entrev dif_acep camb_dom d_nomax_edad {
tab `u'   
}

save "$path\Cruce\Paper descriptivo\Stata\dta\Rouding_INR\variables_2014.dta" ,replace
