version 14.2

clear all
cls
set more off

* Rutas de trabajo

global path "C:\Users\felma.000\Dropbox\Cruce\Paper descriptivo\Stata"
global pathdat "$path\dta"
global efh "$path\efh_dta"
global pathtab "$path\\tablas"

* Se utiliza base de regresiones para identificar datos con match

use "$pathdat\analysis11_14_17_vfix_long.dta"

keep if yearEFH==2017
keep if reporut_2017==1
keep if tipo_deuda==1

* Household complexity variables
* 2011's variables
merge m:1 folio yearEFH  using "$path/dta/caract_hh_11.dta"  ,replace update 
tab _merge year
drop if _merge==2
drop _merge
* 2014's variables
merge m:1 folio yearEFH  using "$path/dta/caract_hh_14.dta"  ,replace update 
tab _merge year
drop if _merge==2
drop _merge
* 2017's variables
merge m:1 folio yearEFH  using "$path/dta/caract_hh_17.dta"   ,replace update 
tab _merge year
drop if _merge==2
drop _merge

* Generación variable de error (copiado de dofiles de refresiones para margen
* extensivo)

* Debt types
g tipo_deudar=tipo_deuda
replace tipo_deudar = 2 if (tipo_deuda == 2| tipo_deuda == 4)
lab def tipo_deudar 1 "Mortgages" 2 "Credit card and lines" 3 "Installment loans" , modify
label values tipo_deudar tipo_deudar

* TL to the logit
replace error_EFH_notSBIF=0 if ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==1) ///
& tipo_deuda==2) | ((deuda_linea_EFH==1 & deuda_linea_SBIF==1) & tipo_deuda==4)

replace error_EFH_notSBIF=1 if ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==0) ///
& tipo_deuda==2) | ((deuda_linea_EFH==1 & deuda_linea_SBIF==0) & tipo_deuda==4)

* Error not EFH and yes SBIF
g error_notEFH_SBIF=.
replace error_notEFH_SBIF=0 if ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==1) & tipo_deuda==4) | ///
((deuda_linea_EFH==1 & deuda_linea_SBIF==1) & tipo_deuda==2)  | ///
((deuda_hipotecario_EFH==1 & deuda_hipotecario_SBIF==1) & tipo_deuda==1) | ///
((deuda_prestamo_EFH==1 & deuda_prestamo_SBIF==1) & tipo_deuda==3)

replace error_notEFH_SBIF=1 if ((deuda_tarjeta_EFH==0 & deuda_tarjeta_SBIF==1) & tipo_deuda==4) | ///
((deuda_linea_EFH==0 & deuda_linea_SBIF==1) & tipo_deuda==2) | ///
((deuda_hipotecario_EFH==0 & deuda_hipotecario_SBIF==1) & tipo_deuda==1) | ///
((deuda_prestamo_EFH==0 & deuda_prestamo_SBIF==1) & tipo_deuda==3)
   
* Error  EFH and not SBIF
g error_EFH_notSBIF_v2=.
replace error_EFH_notSBIF_v2=0 if ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==1) & tipo_deuda==4) | ///
((deuda_linea_EFH==1 & deuda_linea_SBIF==1) & tipo_deuda==2)  | ///
((deuda_hipotecario_EFH==1 & deuda_hipotecario_SBIF==1) & tipo_deuda==1) | ///
((deuda_prestamo_EFH==1 & deuda_prestamo_SBIF==1) & tipo_deuda==3)

replace error_EFH_notSBIF_v2=1 if ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==0) & tipo_deuda==4) | ///
((deuda_linea_EFH==1 & deuda_linea_SBIF==0) & tipo_deuda==2) | ///
((deuda_hipotecario_EFH==1 & deuda_hipotecario_SBIF==0) & tipo_deuda==1) | ///
((deuda_prestamo_EFH==1 & deuda_prestamo_SBIF==0) & tipo_deuda==3) 
   
g tarj_lin=0
replace tarj_lin=1 if  (tipo_deuda==2 | tipo_deuda==4)

g tipo_deudat=1
replace tipo_deudat=2 if  (tipo_deuda==2 | tipo_deuda==4)
replace tipo_deudat=3 if  tipo_deuda==3

* Multinomial dependent variable
gen error_EFH_SBIF=0     if error_EFH_notSBIF_v2==0
replace error_EFH_SBIF=1 if error_EFH_notSBIF_v2==1
replace error_EFH_SBIF=2 if error_notEFH_SBIF==1
lab def error_EFH_SBIF 0 "Reporting both sources" 1 "Reporting only EFH" 2 "Reporting only SBIF"
lab val error_EFH_SBIF error_EFH_SBIF

tab error_EFH_SBIF error_EFH_notSBIF_v2 ,miss
tab error_EFH_SBIF error_notEFH_SBIF ,miss

* Variable ocupacional
g c6_act_indef2=c6_act_indef 
recode c6_act_indef2 2=1 7=1 4=3 6=3
lab def c6_act_indef2 1 "Self-employed" 3 "Civil servant" 5 "Private sector" 8 "Inactive or unemployed" 9 "Pensioner", modify
label values c6_act_indef2 c6_act_indef2
label var c6_act_indef2 "Occupational status"

* Se mantienen variables de interés
keep folio ord yearEFH error_* a1_nothighest_income num_g reporut_2017 a1_nothighest_age ///
 ylab ytotef numh n_act num_adul gen_ing conoc_afp2 sof_fin married uso_docs c6_act_indef2 sof_fin
drop error_ratio0

* Se agrega información de EFH allvars_2017

joinby folio ord using "$efh\EFH_17_allvars.dta", unm(b)
keep if ord==1

* Análisis de titularidad en muestra

tab e14_1 if e21==1
tab e14_2 if e21==1

* Se genera variable que indica si entrevistado está entre los titulares de la
* deuda hipotecaria

g ent_hip=(e14_1==1 | e14_2==1) if e14_1!=.	// Entrevistado titular principal o secundario
g ent_hip1=(e14_1==1) if e14_1!=.			// Entrevistado titular principal

* Participación de los entrevistados en titularidad
tab ent_hip
tab ent_hip if e21==1

* Relación entre error en hipotecaria y entrevistado titular hipotecario
tab error_EFH_SBIF ent_hip if reporut==1 & e14_1!=.
 
tab error_EFH_SBIF ent_hip if reporut==1 & e14_1!=., nof row

* Relación entre error en hipotecaria y entrevistado titular hipotecario, con 
* deuda vigente
tab error_EFH_SBIF ent_hip if reporut==1 & e14_1!=. & e21==1
 
tab error_EFH_SBIF ent_hip if reporut==1 & e14_1!=.  & e21==1, nof row

* análisis para titular principal

* Relación entre error en hipotecaria y entrevistado titular hipotecario
tab error_EFH_SBIF ent_hip1 if reporut==1 & e14_1!=.
 
tab error_EFH_SBIF ent_hip1 if reporut==1 & e14_1!=., nof row

* Relación entre error en hipotecaria y entrevistado titular hipotecario, con 
* deuda vigente
tab error_EFH_SBIF ent_hip1 if reporut==1 & e14_1!=. & e21==1
 
tab error_EFH_SBIF ent_hip1 if reporut==1 & e14_1!=.  & e21==1, nof row

* Modelo Binario para analizar relacion
gen num_g2 =num_g 
recode num_g2 (4=3)
tab num_g2 ,nol

gen education=1 if neduc==1 | neduc==2
replace education=2 if neduc==3
replace education=3 if neduc==4
replace education=4 if neduc==5
label var education "Education"
lab def education 1 "Only school" 2 "Technical education" 3 "University" 4 "Postgraduate" , modify

probit ent_hip1 i.a1_nothighest_income i.num_g2 if reporut==1 & e14_1!=. & error_EFH_SBIF!=.
outreg2 using "$pathtab\probit_titularidad.xls", replace dec(3) addstat(Pseudo R-squared, `e(r2_p)')

probit ent_hip1 i.a1_nothighest_income i.num_g2 c.edad##c.edad i.married i.genero i.education  ///
i.c6_act_indef2  if reporut==1 & e14_1!=. & error_EFH_SBIF!=.
outreg2 using "$pathtab\probit_titularidad.xls", dec(3) addstat(Pseudo R-squared, `e(r2_p)')

probit ent_hip1 i.a1_nothighest_income i.num_g2 c.edad##c.edad i.married i.genero i.education  ///
i.c6_act_indef2 i.sof_fin if reporut==1 & e14_1!=. & error_EFH_SBIF!=.
outreg2 using "$pathtab\probit_titularidad.xls", dec(3) addstat(Pseudo R-squared, `e(r2_p)')

estat clas
lroc

