version 14.2

clear
cls
set more off

* Rutas de trabajo

global path "C:\Users\felma.000\Dropbox\Cruce\Paper descriptivo\Stata"
global pathdat "$path\dta"
global efh "$path\efh_dta"

********************************************************************************
* Do file para generar caracterización de hogares en EFH 2017
********************************************************************************

* Base EFH 2017
use "$efh\EFH_17_allvars.dta"

* Ajuste en composición de hogar

replace a2=7 if folio==2504 & ord==4
replace a2=3 if folio==2991 & ord==5
replace a2=4 if (folio==3214 & ord==4) | (folio==4286 & ord==2)
replace a2=3 if (folio==1459 & ord==1) | (folio==1911 & ord==1) | (folio==2486 & ord==1) ///
				| (folio==3618 & ord==1)
replace a2=6 if (folio==2486 & ord==2)
replace a2=2 if (folio==2486 & ord==4)

*-> Enfoque 1: solo se caracteriza al hogar

* Se identifica si hay menores de edad dependientes
g dependant_ind=1 if edad<=18
replace dependant=1 if n_educ==1
bysort folio: egen dependant=mean(dependant_ind)
recode dependant .=0

* Se identifica si hay mayores de edad estudiando. Se limita a personas bajo los
* 26 años.

g stud_ind=1 if (edad>=18 & edad<=35) & b1==1  & c1==8
bysort folio: egen stud=mean(stud_ind)
recode stud .=0

* Existencia de conyuge del jefe de hogar
g partner_ind=1 if a2==2
bysort folio: egen partner=mean(partner_ind)
recode partner .=0

* Indicador hijo
g child_ind=1 if a2==3 & edad>18 & c1!=8
bysort folio: egen child=mean(child_ind)
recode child .=0

* indicador nietos
g gchild_ind=1 if a2==7 & edad>17 & c1!=8
bysort folio: egen gchild=mean(gchild_ind)
recode gchild .=0

* indicador de padre
g fath_ind=1 if a2==4
bysort folio: egen fath=mean(fath_ind)
recode fath .=0

* Indicador abuelo 
g gfath_ind=1 if a2==10
bysort folio: egen gfath=mean(gfath_ind)
recode gfath .=0

* indicador suegro
g par_law_ind=1 if a2==5
bysort folio: egen par_law=mean(par_law_ind)
recode par_law .=0

* indcador yerno/nuera
g sd_law_ind=1 if a2==6 & c1!=8
bysort folio: egen sd_law=mean(sd_law_ind)
recode sd_law .=0

* Indicador otros adultos
g ot_ad_ind=1 if (a2==8 | a2==9 | a2==11 | a2==12 | a2==13) & edad>18
bysort folio: egen ot_ad=mean(ot_ad_ind)
recode ot_ad .=0

* Tipos de hogares
g hh_type=.
replace hh_type=0 if numh==1														// Hogares unipersonales
replace hh_type=1 if partner==1	& child==0 & sd_law==0 & fath==0 & par_law==0 ///
					& gfath==0  & ot_ad==0 & gchild==0 	& hh_type==.				// pareja
replace hh_type=2 if partner==1	& child==1 & sd_law==0 & fath==0 & par_law==0 ///
					& gfath==0  & ot_ad==0 & gchild==0 & hh_type==. 				// pareja, hijos
replace hh_type=3 if partner==0	& child==1 & gchild==0 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==0 & ot_ad==0 & hh_type==.					// Algun padre, hijo
replace hh_type=4 if partner==0	& child==0 & gchild==0 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==0 & ot_ad==0 & (stud==1 | dependant==1) ///
					& hh_type==. 													// Algun padre, hijo dependiente
replace hh_type=5 if partner==0 & child==0 & gchild==0 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==0 & ot_ad==1& hh_type==.					// non-relative adults
replace hh_type=6 if hh_type==.														// Otros

lab var hh_type "Type of hh"

lab def hh_type 0 "Single-person hh" 1 "couple" 2 "couple with non-dependant children" 3 "Some parent and non-dependant children"
lab def hh_type 4 "Some parent and dependant children" 5 "non-relative adults hh" 6 "Other", add
lab val hh_type hh_type

* Reducción de categorías para hh_type

g hh_type2=0 if hh_type==0 | hh_type==4
replace hh_type2=1 if hh_type==1
replace hh_type2=2 if hh_type==2 | hh_type==3
replace hh_type2=3 if hh_type==5 | hh_type==6 

lab var hh_type2 "Type of hh - grouped)"

lab def hh_type2 0 "one adult in the hh" 1 "couple" 2 "couple or single parent with non-dependant children" 3 "other"
lab val hh_type2 hh_type2

					
/*
g hh_type=.
replace hh_type=0 if numh==1														// Hogares unipersonales
replace hh_type=1 if partner==1	& child==0 & gchild==0 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==0 & ot_ad==0 								// Dos adultos en pareja
replace hh_type=2 if partner==1	& child==1 & gchild==0 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==0 & ot_ad==0 								// pareja, hijos
replace hh_type=3 if partner==1	& child==1 & gchild==0 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==1 & ot_ad==0 								// pareja, hijos, yerno/nuera
replace hh_type=3 if partner==1	& child==1 & gchild==1 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==0 & ot_ad==0 								// pareja, hijos, nietos
replace hh_type=4 if partner==1	& child==1 & gchild==1 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==1 & ot_ad==0 								// pareja, hijos, yerno/nuera, nietos
replace hh_type=5 if partner==1	& child==1 & gchild==0 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==0 & ot_ad==1 								// pareja, hijos, otros adultos
replace hh_type=6 if partner==1	& child==0 & gchild==0 & (fath==1 | par_law==1) ///
					& gfath==0 & sd_law==0 & ot_ad==0 								// pareja, padres
replace hh_type=7 if partner==1	& child==1 & gchild==0 & (fath==1 | par_law==1) ///
					& gfath==0 & sd_law==0 & ot_ad==0 								// pareja, padres, hijos
replace hh_type=8 if partner==1	& child==0 & gchild==0 & (fath==1 | par_law==1) ///
					& gfath==0 & sd_law==0 & ot_ad==1 								// pareja, padres, otros adultos
replace hh_type=9 if partner==1	& child==0 & gchild==0 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==0 & ot_ad==1 								// pareja, otros adultos
replace hh_type=10 if partner==0	& child==1 & gchild==0 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==0 & ot_ad==0 								// Algun padre, hijo 
replace hh_type=12 if partner==0	& child==1 & gchild==0 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==1 & ot_ad==0 								// Algun padre, hijo , yerno/nuera
replace hh_type=13 if partner==0	& child==1 & gchild==1 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==0 & ot_ad==0 								// Algun padre, hijo, nieto
replace hh_type=14 if partner==0	& child==1 & gchild==0 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==0 & ot_ad==1 								// Algun padre, hijo, otro adulto
replace hh_type=15 if partner==0	& child==1 & gchild==0 & fath==1 & par_law==0 ///
					& gfath==0 & sd_law==0 & ot_ad==1 								// Algun padre, hijo, abuelo, otro adulto
replace hh_type=16 if partner==0	& child==0 & gchild==0 & fath==1 & par_law==0 ///
					& gfath==0 & sd_law==0 & ot_ad==1 								// Algun padre, abuelo, otro adulto
replace hh_type=17 if partner==0	& child==0 & gchild==0 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==0 & ot_ad==0 & (stud==1 | dependant==1)	// Algun padre, hijo dependiente
replace hh_type=18 if partner==0 & child==0 & gchild==0 & (fath==1 | par_law==1) ///
					& gfath==0 & sd_law==0 & ot_ad==0								// Hijo, padre
replace hh_type=19 if partner==0 & child==0 & gchild==0 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==0 & ot_ad==1 								// Grupo adultos
replace hh_type=20 if partner==0 & child==0 & gchild==0 & fath==0 & par_law==0 ///
					& gfath==1 & sd_law==0 & ot_ad==0								// Nieto, abuelos
replace hh_type=21 if partner==0 & child==1 & gchild==0 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==1 & ot_ad==1								// algún padre, hijos-yerno/nuera, otro
replace hh_type=22 if partner==0 & child==0 & gchild==0 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==1 & ot_ad==0								// algún padre, yerno/nuera
replace hh_type=23 if partner==0 & child==1 & gchild==0 & (fath==1 | par_law==1) ///
					& gfath==0 & sd_law==0 & ot_ad==0								// algún padre, hijo, abuelo
replace hh_type=24 if partner==0 & child==0 & gchild==0 & (fath==1 | par_law==1) ///
					& gfath==0 & sd_law==0 & ot_ad==1								// algún padre, otro adulto, suegro
replace hh_type=25 if partner==0 & child==0 & gchild==1 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==0 & ot_ad==0								// abuelo, nieto
replace hh_type=26 if partner==1 & child==0 & gchild==0 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==1 & ot_ad==0								// pareja, yerno/nuera	
replace hh_type=26 if partner==0 & child==1 & gchild==1 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==1 & ot_ad==0								// algún padre, hijo-yerno/nuera, nieto, abuelo
replace hh_type=27 if partner==1 & child==0 & gchild==0 & fath==0 & par_law==0 ///
					& gfath==1 & sd_law==0 & ot_ad==0								// pareja, abuelo
replace hh_type=28 if partner==0 & child==1 & gchild==1 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==0 & ot_ad==1								// algun padre, hijo, nieto, otro
replace hh_type=29 if partner==1 & child==0 & gchild==1 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==0 & ot_ad==0								// pareja, nieto
replace hh_type=30 if partner==1 & child==1 & gchild==0 & (fath==1 | par_law==1) ///
					& gfath==0 & sd_law==1 & ot_ad==0								// pareja, padres, hijo-yerno/nuera, suegros
replace hh_type=31 if partner==1 & child==1 & gchild==0 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==1 & ot_ad==1								// pareja, hijo-yerno/nuera, otro
replace hh_type=32 if partner==0 & child==0 & gchild==0 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==0 & ot_ad==1								// algun padre, otro
replace hh_type=33 if partner==1 & child==1 & gchild==1 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==0 & ot_ad==1								// pareja, hijo, nieto, otro
replace hh_type=34 if partner==0 & child==1 & gchild==0 & (fath==1 | par_law==1) ///
					& gfath==0 & sd_law==0 & ot_ad==1								// algún padre, hijo-yerno/nuera, abuelo, otro
replace hh_type=35 if partner==0 & child==0 & gchild==0 & (fath==1 | par_law==1) ///
					& gfath==0 & sd_law==1 & ot_ad==0								// algun padre, yerno/nuera, abuelo
replace hh_type=36 if partner==0 & child==0 & gchild==1 & fath==0 & par_law==0 ///
					& gfath==0 & sd_law==0 & ot_ad==1								// algunabuelo, nieto, otro
replace hh_type=36 if partner==0 & child==0 & gchild==0 & fath==0 & par_law==0 ///
					& gfath==1 & sd_law==0 & ot_ad==1								// jefe, otro , abuelo*/

***********************************************************************************
*-> Enfoque para caracterizar entorno de entrevistado

* Se genera indicador de menor edad de padres
g aux_edad=edad if (a2==1 & ord!=1) | (a2==2 & ord!=1)
bysort folio: egen min_edad=min(aux_edad)

* Tipo de entrevistado
g ent_env=.

* Entrevistado, jefe de hogar, hogar unipersonal
replace ent_env=0 if numh==1

* Entrevistado en el núcleo principal y sin otro núcleo en el hogar: jefe de hogar,
* con pareja sin hijos no dependientes
replace ent_env=1 if ((a2==1 & ord==1) | (a2==2 & ord==1)) & partner==1 & ot_ad==0 ///
				& fath==0 & par_law==0 & child==0 & gchild==0 & ot_ad==0 & ent_env==.

* Entrevistado en el núcleo principal y sin otro núcleo en el hogar: jefe de hogar,
* sin pareja sin hijos no dependientes
replace ent_env=2 if ((a2==1 & ord==1) | (a2==2 & ord==1)) & partner==0 & ot_ad==0 ///
				& fath==0 & par_law==0 & child==0 & gchild==0 & ot_ad==0 & ent_env==.

* Entrevistado en el núcleo principal y con otro núcleo en el hogar: jefe de hogar,
* con ; con hijos no dependientes-yerno/nuera, padres/suegros, gchild o gfath
replace ent_env=3 if ((a2==1 & ord==1) | (a2==2 & ord==1)) & partner==1 ///
					& (ot_ad==1 | fath==1 | par_law==1 | child==1 | gchild==1 | ot_ad==0) & ent_env==.

* Entrevistado en el núcleo principal y con otro núcleo en el hogar: jefe de hogar,
* sin pareja; con hijos no dependientes-yerno/nuera, padres/suegros, gchild o gfath
replace ent_env=4 if ((a2==1 & ord==1) | (a2==2 & ord==1)) & partner==0 ///
					& (ot_ad==1 | fath==1 | par_law==1 | child==1 | gchild==1 | ot_ad==0) & ent_env==.

* Entrevistado no jefe de hogar, hijo de jefe de hogar no dependiente (núcleo principal), con o sin
* pareja
replace ent_env=5 if a2==3 & ord==1 & child==1  & ent_env==.

* Entrevistado no jefe de hogar, hijo de jefe de hogar dependiente (núcleo principal), con o sin
* pareja
replace ent_env=6 if a2==3 & ord==1 & child==0  & ent_env==.

* Otra situación
replace ent_env=7 if ent_env==.

lab var ent_env "Condition of respondent into the hh"

lab def ent_env 0 "Single-person hh" 1 "Resp. + partner belong to main family, no other family"
lab def ent_env 2 "Resp. without partner belongs to main familiy, no other family", add
lab def ent_env 3 "Resp. + partner belong to main familiy, with other family/ies", add
lab def ent_env 4 "Resp. without partner belongs to main familiy, with other family/ies", add
lab def ent_env 5 "Resp. is a non-dependant child/ does not belong to main familiy", add
lab def ent_env 6 "Resp. is a dependant child/ belongs to main familiy", add
lab def ent_env 7 "Other", add

lab val ent_env ent_env

* Caracterización de entrevistado reduciendo categorías

g ent_env2=0 if ent_env==0 | ent_env==1 | ent_env==2
replace ent_env2=1 if ent_env==3 | ent_env==4
replace ent_env2=2 if ent_env==6
replace ent_env2=3 if ent_env==5 | ent_env==7

lab var ent_env2 "Condition of respondent into the hh - grouped"

lab def ent_env2 0 "Resp. belongs to main family, no other family"
lab def ent_env2 1 "Resp. belongs to main familiy, with other family", add
lab def ent_env2 2 "Resp. is a non-dependant child does not belong to main familiy", add
lab def ent_env2 3 "Other", add

lab val ent_env2 ent_env2

*-> Enfoque generacional a través de edad
* Se consideran como "generaciones" los siguientes grupos: 18-35, 35-50, 50-65
* y >65

g gen_ed=1 if edad>=18 & edad<35
replace gen_ed=2 if edad>=35 & edad<50
replace gen_ed=3 if edad>=50 & edad<65
replace gen_ed=4 if edad>=65

* Se cuenta el número de generaciones en cada hogar
bysort folio: egen num_g=nvals(gen_ed)

label var num_g "Number of generationes in the hh"
lab def num_g 1 "Only one generation" 2 "Two generations" 3 "Three generations" 4 "Four generations"
lab val num_g num_g

* Se genera base con datos
keep if ord==1
keep folio hh_type* ent_env* num_g
g yearEFH=2017

save "$pathdat\caract_hh_17.dta", replace
