version 14
clear all
cls
set more off
capture log close

global path "C:\Users\felma.000\Dropbox\Cruce\Paper descriptivo\Stata"
global pathdat "$path\dta"
*global reg "C:\Users\felma\Documents\cruce"
global reg"$path\tablas"

* Base long de PR

use "$pathdat\analysis11_14_17_vfix_long.dta"

* Se une base con infor adicional}

joinby folio yearEFH tipo_deuda using "$path\dta\informacion_deudas.dta", unm(b)

* Análisis logit

* Variables explicativas
***************************************************************************************
egen id=group(folio yearEFH)
gen edad2=edad*edad
gen edad_d=int(edad/10)
label var edad_d "Age (in decades)"
g edadsq=edad_d*edad_d
label var edadsq "Age (in decades) squared"
gen terc_educ=(neduc>3)
label var terc_educ "Interviewed holds a post-secondary degree"
gen relationship =(est_civ==2)
label var relationship "In a relationship"
gen sobr_end=(perc_end==1|perc_end==2)
label var sobr_end "Household feels over-indebted"
gen       int_knowledge=(x_n3==3)
label var int_knowledge   "Good knowledge of the interviewed"
gen       int_disposition=(x_n5==3)
label var int_disposition "Good disposition of the interviewed"
g c6_act_indef2=c6_act_indef 
recode c6_act_indef2 2=1 7=1 4=3 6=3
lab def c6_act_indef2 1 "Self-employed" 3 "Civil servant" 5 "Private sector" 8 "Inactive or unemployed" 9 "Pensioner", modify
label values c6_act_indef2 c6_act_indef2
label var c6_act_indef2 "Occupational status"
gen n_cconhip=n_ccon+n_chip
label var n_cconhip "Number of loans"
gen p_estrato3   =(estrato==3)
label var p_estrato3 "If household belongs to highest 2 deciles"
/* Not working here
gen tipo_d=(tipo==9)
label var tipo_d "Type of banking debt"
lab def tipo_d 0 "Installment loan" 1 "Mortgage loan" , modify
label values tipo_d tipo_d
*/
gen education=1 if neduc==1 | neduc==2
replace education=2 if neduc==3
replace education=3 if neduc==4
replace education=4 if neduc==5
label var education "Education"
lab def education 1 "Only school" 2 "Technical education" 3 "University" 4 "Postgraduate" , modify
label values education education

gen male_nmarried=(genero==1 & married==0)
label var male_nmarried "Male, not married"
/*bys folio yearEFH: egen atr_12m_h=max(atr_12m)
label var atr_12m_h "Interviewed has had credit arrears in last 12 months"
*/

***************************************************************************************
* Version FM, with debt ownership status (EFH=1,SBIF=0)
***************************************************************************************

set more off
logit error_EFH_notSBIF $explic_var3 $adicional2 [pw=factor_egm], vce(cluster folio)

* Se incorporan tarjetas y líneas

replace error_EFH_notSBIF=0 if ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==1) ///
							& tipo_deuda==2) | ((deuda_linea_EFH==1 & deuda_linea_SBIF==1) & tipo_deuda==4)
replace error_EFH_notSBIF=1 if ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==0) ///
							& tipo_deuda==2) | ((deuda_linea_EFH==1 & deuda_linea_SBIF==0) & tipo_deuda==4)

* Modelos Logit para hipotecario

global lista "hip con tl tot"
global cond1 "if tipo_deuda==1 & reporut_2017!=0"
global cond2 "if tipo_deuda==3 & reporut_2017!=0"
global cond3 "if (tipo_deuda==2 | tipo_deuda==4) & reporut_2017!=0" // , vce(cluster id)"
global cond4 "if (tipo_deuda==1 | tipo_deuda==2 | tipo_deuda==3 | tipo_deuda==4) & reporut_2017!=0 , vce(cluster id)"

global ad1 " "
global ad2 " "
global ad3 "i.tipo_deuda"
global ad4 "i.tipo_deuda"

forv k=1/4 {

		local x=word("$lista",`k')
		di "`x'"		
		
		logit error_EFH_notSBIF c.edad##c.edad i.genero i.married i.education i.c6_act_indef2 i.estrato num_adul ///
		${ad`k'} [pw=factor_egm] ${cond`k'}

		outreg2 using "$reg\regresiones_FM_`x'_logit.xls" , replace ctitle(Model 1)

		logit error_EFH_notSBIF c.edad##c.edad i.genero i.married i.education i.c6_act_indef2 i.estrato num_adul ///
		i.d_nomax_ing i.d_nomax_edad n_act n_ing ${ad`k'} [pw=factor_egm] ${cond`k'}

		outreg2 using "$reg\regresiones_FM_`x'_logit.xls" , append ctitle(Model 2)

		logit error_EFH_notSBIF c.edad##c.edad i.genero i.married i.education i.c6_act_indef2 i.estrato num_adul ///
		i.d_nomax_ing i.d_nomax_edad n_act n_ing i.d_transf ///
		i.refresco i.macrozona ${ad`k'} [pw=factor_egm] ${cond`k'}

		outreg2 using "$reg\regresiones_FM_`x'_logit.xls" , append ctitle(Model 3)

		logit error_EFH_notSBIF c.edad##c.edad i.genero i.married i.education i.c6_act_indef2 i.estrato num_adul ///
		i.d_nomax_ing i.d_nomax_edad n_act n_ing i.d_transf  ///
		i.refresco i.macrozona i.jefe_hog /// 
		i.yearEFH ${ad`k'} [pw=factor_egm] ${cond`k'}

		outreg2 using "$reg\regresiones_FM_`x'_logit.xls" , append ctitle(Model 4)

		logit error_EFH_notSBIF c.edad##c.edad i.genero i.married i.education i.c6_act_indef2 i.estrato num_adul ///
		i.d_nomax_ing i.d_nomax_edad n_act n_ing i.d_transf i.refresco ///
		i.macrozona i.jefe_hog i.yearEFH ///
		n_cconhip ${ad`k'} [pw=factor_egm] ${cond`k'}

		outreg2 using "$reg\regresiones_FM_`x'_logit.xls" , append ctitle(Model 5)

		logit error_EFH_notSBIF c.edad##c.edad i.genero i.married i.education i.c6_act_indef2 num_adul ///
		i.d_nomax_ing i.d_nomax_edad n_act n_ing i.d_transf i.refresco i.macrozona i.jefe_hog i.yearEFH ///
		n_cconhip ${ad`k'}  [pw=factor_egm] ${cond`k'}
		
		outreg2 using "$reg\regresiones_FM_`x'_logit.xls" , append ctitle(Model 6)
}


* porque error_EFH_notSBIF es 0 cuando deuda_hipotecaria_SBIF==. ... que quiere decir lo ultimo
* n_preg_e solo para 2014 y 2017
***************************************************************************************
* Version FM, proportional errors (EFH=1,SBIF=0)
***************************************************************************************

g error_abs=100*abs(error_ratio0) if error_ratio0>=-2 & error_ratio0<=2

global lista "hip con tl tot"
global cond1 " tipo_deuda==1 & (deuda_hipotecario_EFH==1 & deuda_hipotecario_SBIF==1)"
global cond2 " tipo_deuda==3 & (deuda_prestamo_EFH==1 & deuda_prestamo_SBIF==1)"
global cond3_1 " (tipo_deuda==2 | tipo_deuda==4) &"
global cond3_2 " ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==1)  | (deuda_linea_EFH==1 & deuda_linea_SBIF==1))"
global cond3 " $cond3_1 $cond3_2 , vce(cluster id)"
global cond4 " $cond1 | $cond2 | ($cond3_1 $cond3_2) , vce(cluster id)"

global ad1 "n_ccon "
global ad2 "n_chip "
global ad3 "n_chip i.tipo_deuda"
global ad4 "i.tipo_deuda"

forv k=1/4 {

	local x=word("$lista",`k')
	di "`x'"

	reg error_ratio0 c.edad##c.edad i.genero i.married i.education i.c6_act_indef2 i.estrato num_adul ///
	${ad`k'} [pw=factor_egm] if reporut_2017!=0 & ${cond`k'}

	outreg2 using "$reg\regresiones_FM_`x'_error.xls" , replace ctitle(Model 1)

	reg error_ratio0 c.edad##c.edad i.genero i.married i.education i.c6_act_indef2 i.estrato num_adul ///
	i.sobr_end i.d_nomax_ing i.d_nomax_edad n_act n_ing i.d_transf ${ad`k'} [pw=factor_egm] if reporut_2017!=0 & ${cond`k'}

	outreg2 using "$reg\regresiones_FM_`x'_error.xls" , append ctitle(Model 2)

	reg error_ratio0 c.edad##c.edad i.genero i.married i.education i.c6_act_indef2 i.estrato num_adul ///
	i.sobr_end i.d_nomax_ing i.d_nomax_edad n_act n_ing i.d_transf ///
	i.refresco i.macrozona ${ad`k'} [pw=factor_egm] if reporut_2017!=0 & ${cond`k'}

	outreg2 using "$reg\regresiones_FM_`x'_error.xls" , append ctitle(Model 3)

	reg error_ratio0 c.edad##c.edad i.genero i.married i.education i.c6_act_indef2 i.estrato num_adul ///
	i.sobr_end i.d_nomax_ing i.d_nomax_edad n_act n_ing i.d_transf ///
	i.refresco i.macrozona i.jefe_hog /// 
	i.yearEFH ${ad`k'} [pw=factor_egm] if reporut_2017!=0 & ${cond`k'}

	outreg2 using "$reg\regresiones_FM_`x'_error.xls" , append ctitle(Model 4)

	reg error_ratio0 c.edad##c.edad i.genero i.married i.education i.c6_act_indef2 i.estrato num_adul ///
	i.sobr_end i.d_nomax_ing i.d_nomax_edad n_act n_ing i.d_transf i.refresco ///
	i.macrozona i.jefe_hog i.yearEFH ///
	${ad`k'} [pw=factor_egm] if reporut_2017!=0 & ${cond`k'}

	outreg2 using "$reg\regresiones_FM_`x'_error.xls" , append ctitle(Model 5)

	reg error_ratio0 c.edad##c.edad i.genero i.married i.education i.c6_act_indef2 num_adul ///
	i.d_nomax_ing i.d_nomax_edad n_act n_ing i.d_transf i.refresco i.macrozona i.jefe_hog i.yearEFH ///
	${ad`k'} [pw=factor_egm] if reporut_2017!=0 & ${cond`k'}
	
	outreg2 using "$reg\regresiones_FM_`x'_error.xls" , append ctitle(Model 6)
}


* Comparación entre todos lso individuos con deuda y solo aquellos que reportan en ambas fuentes

global lista "hip con tl tot"
global tipo1 "tipo_deuda==1"
global tipo2 "tipo_deuda==3"
global tipo3 "(tipo_deuda==2 | tipo_deuda==4)"
global tipo4 "(tipo_deuda==1 | tipo_deuda==2 | tipo_deuda==3 | tipo_deuda==4)"
global cond1 "(deuda_hipotecario_EFH==1 & deuda_hipotecario_SBIF==1)"
global cond2 "(deuda_prestamo_EFH==1 & deuda_prestamo_SBIF==1)"
global cond3 " ((deuda_tarjeta_EFH==1 & deuda_tarjeta_SBIF==1)  | (deuda_linea_EFH==1 & deuda_linea_SBIF==1))"
global cond4 " ($tipo1 & $cond1) | ($tipo2 & $cond2) | ($tipo3 & $cond3)"


forv k=1/4 {

	local x=word("$lista",`k')
	di "`x'"
	
	sum error_abs if reporut_2017!=0 & ${tipo`k'}  & ${cond`k'}

	
	reg error_abs c.edad##c.edad i.genero i.married i.education i.c6_act_indef2 i.estrato num_adul ///
	n_act d_transf i.refresco [pw=factor_egm] if reporut_2017!=0 & ${tipo`k'} , vce(cluster id)

	outreg2 using "$reg\regresiones_FM_comp_error_`x'.xls" , replace ctitle(Model 1)
	
	reg error_abs c.edad##c.edad i.genero i.married i.education i.c6_act_indef2 i.estrato num_adul ///
	n_act d_transf i.refresco [pw=factor_egm] if reporut_2017!=0 & ${tipo`k'} & ${cond`k'}, vce(cluster id)


	outreg2 using "$reg\regresiones_FM_comp_error_`x'.xls" , append ctitle(Model 1')
	
	reg error_abs c.edad##c.edad i.genero i.married i.education i.c6_act_indef2 i.estrato num_adul ///
	n_act d_transf i.refresco i.d_nomax_ing /// 
	[pw=factor_egm] if reporut_2017!=0 & ${tipo`k'}, vce(cluster id)


	outreg2 using "$reg\regresiones_FM_comp_error_`x'.xls" , append ctitle(Model 2)
	
	reg error_abs c.edad##c.edad i.genero i.married i.education i.c6_act_indef2  num_adul  ///
	n_act d_transf i.refresco i.d_nomax_ing  /// 
	[pw=factor_egm] if reporut_2017!=0 &  ${tipo`k'} & ${cond`k'}, vce(cluster id)


	outreg2 using "$reg\regresiones_FM_comp_error_`x'.xls" , append ctitle(Model 2')
}
