version 14.2
clear
drop _all
cls

global path "C:\Users\felma.000\Dropbox\Cruce"
global pathdat "$path\Paper descriptivo\Stata\dta"
global dat "$path\Paper_use_docs\2019\Stata\dta"

* Se abre base de cruce EFH-SBIF a nivel de deuda. Base construída para paper de
* uso de documentos.

use "$dat\Cruce_EFH_SBIF_11_14_17_match.dta"

* Variable indicador de matcheo es match. No está el número de deuda por cada
* tipo de deuda, por lo que se crea agrupación folio, año de encuesta, tipo de 
* en la sbif para identificar folio con varias deudas del mismo tipo en un año 
* particular.

keep if match==1

* Se genera diferencia entre fecha de registro de crédito en al SBIF y fecha de 
* entrevista en la EFH

g time_elapsed=t_entrevista-fecha_cred

*-> Se construyen 3 variables para identificar el tiempo transcurrido desde el 
*   otorgamiento del crédito.

* i) max_elapsed: indica el tiempo transcurrido entre la deuda más antigua y 
* la fecha de la entrevista. Esta variable es útil ya que cuando ha mientras más
* distante una deuda en el tiempo es probable que el reporte sea de menor 
* calidad

bysort folio year_efh tipo: egen max_elapsed=max(time_elapsed)

* ii) prom_elapsed: se genera un promedio del tiempo transcurrido entre la fecha
* de originación de los créditos y la fecha de la entrevista. Para cubrir
* alternativas, se genera un promedio simple (prom_elapsed_s) y un promedio
* ponderado de acuerdo al monto original del crédito en la SBIF

bysort folio year_efh tipo: egen prom_elapsed_s=mean(time_elapsed)

bysort folio year_efh tipo: egen w=pc(mo_deu), prop
bysort folio year_efh tipo: egen prom_elapsed_p=wtmean(time_elapsed), weight(w)

collapse time_elapsed max_elapsed prom_elapsed_*, by(folio year_efh tipo)

drop time_elapsed
reshape wide max_elapsed prom_elapsed_s prom_elapsed_p, i(folio year_efh) j(tipo)

rename max_elapsed* max_elapsed_*
rename prom_elapsed_s* prom_elapsed_s_*
rename prom_elapsed_p* prom_elapsed_p_*

foreach k in 5 9 {
lab var max_elapsed_`k' "Distancia en meses entre deuda más antigua y fecha de entrevista tipo `k'"
lab var prom_elapsed_s_`k' "Promedio simple de la distancia en meses de las deudas con la fecha de entrevista tipo `k'"
lab var prom_elapsed_p_`k' "Promedio de la distancia en meses de las deudas con la fecha de entrevista ponderado por monto de original de la deuda tipo `k'"
}

save "$pathdat\base_time_elapsed.dta", replace
